summaryrefslogtreecommitdiffstats
path: root/vcs/cvsservice
diff options
context:
space:
mode:
Diffstat (limited to 'vcs/cvsservice')
-rw-r--r--vcs/cvsservice/Makefile.am2
-rw-r--r--vcs/cvsservice/README.dox4
-rw-r--r--vcs/cvsservice/annotatedialog.cpp4
-rw-r--r--vcs/cvsservice/annotatedialog.h3
-rw-r--r--vcs/cvsservice/annotatepage.cpp8
-rw-r--r--vcs/cvsservice/annotatepage.h3
-rw-r--r--vcs/cvsservice/annotateview.cpp30
-rw-r--r--vcs/cvsservice/annotateview.h7
-rw-r--r--vcs/cvsservice/bufferedstringreader.cpp2
-rw-r--r--vcs/cvsservice/changelog.cpp2
-rw-r--r--vcs/cvsservice/changelog.h2
-rw-r--r--vcs/cvsservice/checkoutdialog.cpp6
-rw-r--r--vcs/cvsservice/checkoutdialog.h3
-rw-r--r--vcs/cvsservice/checkoutdialogbase.ui38
-rw-r--r--vcs/cvsservice/commitdialogbase.ui24
-rw-r--r--vcs/cvsservice/commitdlg.cpp4
-rw-r--r--vcs/cvsservice/commitdlg.h3
-rw-r--r--vcs/cvsservice/cvsdiffpage.cpp4
-rw-r--r--vcs/cvsservice/cvsdiffpage.h3
-rw-r--r--vcs/cvsservice/cvsdir.cpp18
-rw-r--r--vcs/cvsservice/cvsdir.h8
-rw-r--r--vcs/cvsservice/cvsentry.cpp14
-rw-r--r--vcs/cvsservice/cvsfileinfoprovider.cpp36
-rw-r--r--vcs/cvsservice/cvsfileinfoprovider.h5
-rw-r--r--vcs/cvsservice/cvsform.cpp4
-rw-r--r--vcs/cvsservice/cvsform.h3
-rw-r--r--vcs/cvsservice/cvsformbase.ui24
-rw-r--r--vcs/cvsservice/cvslogdialog.cpp6
-rw-r--r--vcs/cvsservice/cvslogdialog.h3
-rw-r--r--vcs/cvsservice/cvslogpage.cpp10
-rw-r--r--vcs/cvsservice/cvslogpage.h3
-rw-r--r--vcs/cvsservice/cvsoptions.cpp6
-rw-r--r--vcs/cvsservice/cvsoptionswidget.cpp4
-rw-r--r--vcs/cvsservice/cvsoptionswidget.h3
-rw-r--r--vcs/cvsservice/cvsoptionswidgetbase.ui30
-rw-r--r--vcs/cvsservice/cvspart.cpp42
-rw-r--r--vcs/cvsservice/cvspart.h7
-rw-r--r--vcs/cvsservice/cvspartimpl.cpp8
-rw-r--r--vcs/cvsservice/cvspartimpl.h3
-rw-r--r--vcs/cvsservice/cvsprocesswidget.cpp20
-rw-r--r--vcs/cvsservice/cvsprocesswidget.h3
-rw-r--r--vcs/cvsservice/diffdialog.cpp10
-rw-r--r--vcs/cvsservice/diffdialog.h3
-rw-r--r--vcs/cvsservice/diffdialogbase.ui36
-rw-r--r--vcs/cvsservice/diffwidget.cpp16
-rw-r--r--vcs/cvsservice/diffwidget.h10
-rw-r--r--vcs/cvsservice/editorsdialog.cpp8
-rw-r--r--vcs/cvsservice/editorsdialog.h3
-rw-r--r--vcs/cvsservice/editorsdialogbase.ui12
-rw-r--r--vcs/cvsservice/integrator/Makefile.am2
-rw-r--r--vcs/cvsservice/integrator/cvsserviceintegrator.cpp10
-rw-r--r--vcs/cvsservice/integrator/cvsserviceintegrator.h7
-rw-r--r--vcs/cvsservice/integrator/fetcherdlgbase.ui20
-rw-r--r--vcs/cvsservice/integrator/initdlg.ui8
-rw-r--r--vcs/cvsservice/integrator/integratordlg.cpp14
-rw-r--r--vcs/cvsservice/integrator/integratordlg.h3
-rw-r--r--vcs/cvsservice/integrator/integratordlgbase.ui36
-rw-r--r--vcs/cvsservice/releaseinputdialog.cpp6
-rw-r--r--vcs/cvsservice/releaseinputdialog.h5
-rw-r--r--vcs/cvsservice/releaseinputdialogbase.ui36
-rw-r--r--vcs/cvsservice/tagdialog.cpp4
-rw-r--r--vcs/cvsservice/tagdialog.h3
-rw-r--r--vcs/cvsservice/tagdialogbase.ui24
63 files changed, 355 insertions, 333 deletions
diff --git a/vcs/cvsservice/Makefile.am b/vcs/cvsservice/Makefile.am
index 04802374..a97444c2 100644
--- a/vcs/cvsservice/Makefile.am
+++ b/vcs/cvsservice/Makefile.am
@@ -1,7 +1,7 @@
# Here resides the cvs part
INCLUDES = -I$(top_srcdir)/lib/interfaces \
- -I$(top_srcdir)/lib/interfaces/extensions -I$(top_srcdir)/lib/util -I$(top_srcdir)/lib/widgets $(all_includes)
+ -I$(top_srcdir)/lib/interfaces/extensions -I$(top_srcdir)/lib/util -I$(top_srcdir)/lib/widgets $(all_includes) -I$(kde_includes)/kde
kde_module_LTLIBRARIES = libkdevcvsservice.la
libkdevcvsservice_la_LDFLAGS = $(all_libraries) $(KDE_PLUGIN)
diff --git a/vcs/cvsservice/README.dox b/vcs/cvsservice/README.dox
index c89e9422..3a102ce7 100644
--- a/vcs/cvsservice/README.dox
+++ b/vcs/cvsservice/README.dox
@@ -23,7 +23,7 @@ mailing list. Contributions are always welcome :-)
Implementation of this component is done by:
- class CvsServicePart, which does provide integration within kdevelop, set-up GUI
integration, forward cvs commands to the implementation (m_impl). It does also
- intercepts signals like "new files added to project" and "... removed from ...".
+ intercepts Q_SIGNALS like "new files added to project" and "... removed from ...".
- class CvsServicePartImpl implements the actual feature: more general speaking
functions (like checking for whether files are in repository, provide checks
on file lists, ...).
@@ -73,7 +73,7 @@ Implementation of this component is done by:
\todo Test with SSH repositories!
\todo Share a common outputview between VCS: CvsProcessWidget should be reworked :-/
-\todo Additional slots for more complex stuff as status, revert, patch creation, ...
+\todo Additional Q_SLOTS for more complex stuff as status, revert, patch creation, ...
\faq <b>Does cvsservicepart support login with :pserver: or :ext: ?</b>
Well, I dunno ;-) I have no ssh repositories to test so feel free to provide feedback on the subject :-)
diff --git a/vcs/cvsservice/annotatedialog.cpp b/vcs/cvsservice/annotatedialog.cpp
index 2937b2bb..d61aeb72 100644
--- a/vcs/cvsservice/annotatedialog.cpp
+++ b/vcs/cvsservice/annotatedialog.cpp
@@ -23,9 +23,9 @@
#include "annotatedialog.h"
#include "annotatepage.h"
-AnnotateDialog::AnnotateDialog( CvsService_stub *cvsService, TQWidget *parent, const char *name, int )
+AnnotateDialog::AnnotateDialog( CvsService_stub *cvsService, TQWidget *tqparent, const char *name, int )
: KDialogBase( Tabbed, i18n("CVS Annotate Dialog"), Close, Close,
- parent, name? name : "annotateformdialog", false /*modal*/, true /*separator*/ ),
+ tqparent, name? name : "annotateformdialog", false /*modal*/, true /*separator*/ ),
m_cvsService( cvsService )
{
setWFlags( getWFlags() | WDestructiveClose );
diff --git a/vcs/cvsservice/annotatedialog.h b/vcs/cvsservice/annotatedialog.h
index c887264d..c6866967 100644
--- a/vcs/cvsservice/annotatedialog.h
+++ b/vcs/cvsservice/annotatedialog.h
@@ -30,8 +30,9 @@ class AnnotatePage;
class AnnotateDialog : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- AnnotateDialog( CvsService_stub *cvsService, TQWidget *parent=0, const char *name=0, int flags=0 );
+ AnnotateDialog( CvsService_stub *cvsService, TQWidget *tqparent=0, const char *name=0, int flags=0 );
virtual ~AnnotateDialog();
/**
diff --git a/vcs/cvsservice/annotatepage.cpp b/vcs/cvsservice/annotatepage.cpp
index 71918304..68e12f6d 100644
--- a/vcs/cvsservice/annotatepage.cpp
+++ b/vcs/cvsservice/annotatepage.cpp
@@ -32,9 +32,9 @@
#include "annotatepage.h"
#include "annotateview.h"
-AnnotatePage::AnnotatePage( CvsService_stub *cvsService, TQWidget *parent, const char *name, int )
+AnnotatePage::AnnotatePage( CvsService_stub *cvsService, TQWidget *tqparent, const char *name, int )
: DCOPObject( "CvsAnnotatePageDCOPIface" ),
- TQWidget( parent, name? name : "annotateformpage" ),
+ TQWidget( tqparent, name? name : "annotateformpage" ),
m_cvsService( cvsService ), m_cvsAnnotateJob( 0 )
{
kdDebug(9006) << "AnnotatePage::AnnotatePage()" << endl;
@@ -106,7 +106,7 @@ void AnnotatePage::slotJobExited( bool normalExit, int exitStatus )
if (!normalExit)
{
- KMessageBox::sorry( this, i18n("Annotate failed with exitStatus == %1").arg( exitStatus), i18n("Annotate Failed") );
+ KMessageBox::sorry( this, i18n("Annotate failed with exitStatus == %1").tqarg( exitStatus), i18n("Annotate Failed") );
return;
}
@@ -140,7 +140,7 @@ void AnnotatePage::parseAnnotateOutput(TQStringList& lines)
* First we need to parse the output of "cvs log" which the dcop-interface delivers
* everytime annotate is requested.
* The TQMap m_comments stores the revisions together with the matching comments.
- * The comments will be passed to the AnnotateView in order to display them as QToolTip
+ * The comments will be passed to the AnnotateView in order to display them as TQToolTip
*/
TQString line, comment, rev;
diff --git a/vcs/cvsservice/annotatepage.h b/vcs/cvsservice/annotatepage.h
index 0b5ab001..27a75314 100644
--- a/vcs/cvsservice/annotatepage.h
+++ b/vcs/cvsservice/annotatepage.h
@@ -37,12 +37,13 @@ class KPushButton;
class AnnotatePage : public TQWidget, virtual public CVSServiceDCOPIface
{
Q_OBJECT
+ TQ_OBJECT
friend class AnnotateDialog;
friend class AnnotateView;
public:
- AnnotatePage( CvsService_stub *cvsService, TQWidget *parent=0, const char *name=0, int flags=0 );
+ AnnotatePage( CvsService_stub *cvsService, TQWidget *tqparent=0, const char *name=0, int flags=0 );
virtual ~AnnotatePage();
/**
diff --git a/vcs/cvsservice/annotateview.cpp b/vcs/cvsservice/annotateview.cpp
index afc185cd..30e80a21 100644
--- a/vcs/cvsservice/annotateview.cpp
+++ b/vcs/cvsservice/annotateview.cpp
@@ -25,14 +25,14 @@
#include "annotatepage.h"
-class AnnotateViewItem : public QListViewItem
+class AnnotateViewItem : public TQListViewItem
{
friend class AnnotateView;
public:
enum { LineNumberColumn, AuthorColumn, DateColumn,ContentColumn };
- AnnotateViewItem(AnnotateView *parent, TQString rev, TQString author,
+ AnnotateViewItem(AnnotateView *tqparent, TQString rev, TQString author,
TQDateTime date, TQString content, TQString comment,
bool odd, int linenumber);
@@ -57,10 +57,10 @@ private:
const int AnnotateViewItem::BORDER = 4;
-AnnotateViewItem::AnnotateViewItem(AnnotateView *parent, TQString rev,
+AnnotateViewItem::AnnotateViewItem(AnnotateView *tqparent, TQString rev,
TQString author, TQDateTime date, TQString content, TQString comment,
bool odd, int linenumber)
- : TQListViewItem(parent)
+ : TQListViewItem(tqparent)
, m_revision(rev)
, m_author(author)
, m_content(content)
@@ -96,7 +96,7 @@ TQString AnnotateViewItem::text(int col) const
;
};
- return TQString::null;
+ return TQString();
}
@@ -140,22 +140,22 @@ int AnnotateViewItem::width(const TQFontMetrics &fm, const TQListView *, int col
/*****************Definition of class AnnotateView ****************************/
/******************************************************************************/
-AnnotateView::AnnotateView(AnnotatePage *parent, const char *name)
- : KListView(parent, name), TQToolTip( viewport() ),
- m_page(parent)
+AnnotateView::AnnotateView(AnnotatePage *tqparent, const char *name)
+ : KListView(tqparent, name), TQToolTip( viewport() ),
+ m_page(tqparent)
{
setFrameStyle(TQFrame::WinPanel | TQFrame::Sunken);
setAllColumnsShowFocus(true);
setShowToolTips(false);
header()->hide();
- addColumn(TQString::null);
- addColumn(TQString::null);
- addColumn(TQString::null);
- addColumn(TQString::null);
+ addColumn(TQString());
+ addColumn(TQString());
+ addColumn(TQString());
+ addColumn(TQString());
setSorting(AnnotateViewItem::LineNumberColumn);
- setColumnAlignment(AnnotateViewItem::LineNumberColumn, Qt::AlignRight);
+ setColumnAlignment(AnnotateViewItem::LineNumberColumn, TQt::AlignRight);
connect( this, TQT_SIGNAL(executed(TQListViewItem*)),
this, TQT_SLOT(itemClicked(TQListViewItem*)) );
@@ -170,7 +170,7 @@ void AnnotateView::addLine(TQString rev, TQString author, TQDateTime date,
}
-TQSize AnnotateView::sizeHint() const
+TQSize AnnotateView::tqsizeHint() const
{
TQFontMetrics fm(fontMetrics());
return TQSize(100 * fm.width("0"), 20 * fm.lineSpacing());
@@ -189,7 +189,7 @@ void AnnotateView::maybeTip( const TQPoint & p )
return;
}
- TQRect r = itemRect( item );
+ TQRect r = tqitemRect( item );
//get the dimension of the author + the date column
TQRect headerRect = header()->sectionRect(AnnotateViewItem::AuthorColumn);
headerRect = headerRect.unite(header()->sectionRect(AnnotateViewItem::DateColumn));
diff --git a/vcs/cvsservice/annotateview.h b/vcs/cvsservice/annotateview.h
index 74d19718..99d222a3 100644
--- a/vcs/cvsservice/annotateview.h
+++ b/vcs/cvsservice/annotateview.h
@@ -30,18 +30,19 @@ class AnnotatePage;
* to get a new page which shows the annotate output
* of the clicked revision.
*/
-class AnnotateView : public KListView, public QToolTip
+class AnnotateView : public KListView, public TQToolTip
{
Q_OBJECT
+ TQ_OBJECT
public:
- explicit AnnotateView(AnnotatePage *parent, const char *name=0 );
+ explicit AnnotateView(AnnotatePage *tqparent, const char *name=0 );
void addLine(TQString rev, TQString author, TQDateTime date, TQString content,
TQString comment, bool odd);
- virtual TQSize sizeHint() const;
+ virtual TQSize tqsizeHint() const;
void maybeTip( const TQPoint & p );
private:
diff --git a/vcs/cvsservice/bufferedstringreader.cpp b/vcs/cvsservice/bufferedstringreader.cpp
index bdaa26f3..f9d1ecb2 100644
--- a/vcs/cvsservice/bufferedstringreader.cpp
+++ b/vcs/cvsservice/bufferedstringreader.cpp
@@ -34,7 +34,7 @@ TQStringList BufferedStringReader::process( const TQString &otherChars )
TQStringList strings;
// Now find all the basic strings in the buffer
int pos;
- while ( (pos = m_stringBuffer.find('\n')) != -1)
+ while ( (pos = m_stringBuffer.tqfind('\n')) != -1)
{
TQString line = m_stringBuffer.left( pos );
if (!line.isEmpty())
diff --git a/vcs/cvsservice/changelog.cpp b/vcs/cvsservice/changelog.cpp
index 1e676f43..18deee0f 100644
--- a/vcs/cvsservice/changelog.cpp
+++ b/vcs/cvsservice/changelog.cpp
@@ -24,7 +24,7 @@ ChangeLogEntry::ChangeLogEntry()
authorEmail = emailConfig.getSetting( KEMailSettings::EmailAddress );
authorName = emailConfig.getSetting( KEMailSettings::RealName );
- TQDate currDate = TQDate::currentDate();
+ TQDate currDate = TQDate::tqcurrentDate();
date = currDate.toString( "yyyy-MM-dd" );
}
diff --git a/vcs/cvsservice/changelog.h b/vcs/cvsservice/changelog.h
index a1b50ffa..ed4d165b 100644
--- a/vcs/cvsservice/changelog.h
+++ b/vcs/cvsservice/changelog.h
@@ -31,7 +31,7 @@ public:
void addLines( const TQStringList &someLines );
//! Pretty format for this entry: you may insert a line tag (such as tab ("\t") or 4 spaces (" ")
//! or whatever you want (such as "\t * ")
- TQString toString( const TQString &startLineString = TQString::null ) const;
+ TQString toString( const TQString &startLineString = TQString() ) const;
//! Once the entry is completed one would like to write on a file! (You may add on start of file
//! prepend == true, or append on tail (prepend == false)
void addToLog( const TQString &logFilePath, const bool prepend = true, const TQString &startLineString = "\t" );
diff --git a/vcs/cvsservice/checkoutdialog.cpp b/vcs/cvsservice/checkoutdialog.cpp
index 82c64052..098dd98e 100644
--- a/vcs/cvsservice/checkoutdialog.cpp
+++ b/vcs/cvsservice/checkoutdialog.cpp
@@ -68,9 +68,9 @@ public:
///////////////////////////////////////////////////////////////////////////////
CheckoutDialog::CheckoutDialog( CvsService_stub *cvsService,
- TQWidget *parent, const char *name, WFlags ) :
+ TQWidget *tqparent, const char *name, WFlags ) :
DCOPObject( "CheckoutDialogDCOPIface" ),
- KDialogBase( parent, name? name : "checkoutdialog", true, i18n("CVS Checkout"),
+ KDialogBase( tqparent, name? name : "checkoutdialog", true, i18n("CVS Checkout"),
Ok | Cancel, Ok, true ),
m_service( cvsService ), m_job( 0 )
{
@@ -257,7 +257,7 @@ void CheckoutDialog::fetchUserCvsRepositories()
void CheckoutDialog::slotOk()
{
- TQString errorMessage = TQString::null;
+ TQString errorMessage = TQString();
if (!(workDir().length() > 0) && TQFile::exists( workDir() ))
errorMessage = i18n( "Please, choose a valid working directory" );
diff --git a/vcs/cvsservice/checkoutdialog.h b/vcs/cvsservice/checkoutdialog.h
index 0d01de69..422290d0 100644
--- a/vcs/cvsservice/checkoutdialog.h
+++ b/vcs/cvsservice/checkoutdialog.h
@@ -30,8 +30,9 @@ class TQListViewItem;
class CheckoutDialog : public KDialogBase, virtual public CVSServiceDCOPIface
{
Q_OBJECT
+ TQ_OBJECT
public:
- CheckoutDialog( CvsService_stub *cvsService, TQWidget *parent = 0,
+ CheckoutDialog( CvsService_stub *cvsService, TQWidget *tqparent = 0,
const char *name = 0, WFlags f = 0 );
virtual ~CheckoutDialog();
diff --git a/vcs/cvsservice/checkoutdialogbase.ui b/vcs/cvsservice/checkoutdialogbase.ui
index f0ebdf8d..8b882b9e 100644
--- a/vcs/cvsservice/checkoutdialogbase.ui
+++ b/vcs/cvsservice/checkoutdialogbase.ui
@@ -1,6 +1,6 @@
<!DOCTYPE UI><UI version="3.3" stdsetdef="1">
<class>CheckoutDialogBase</class>
-<widget class="QWidget">
+<widget class="TQWidget">
<property name="name">
<cstring>CheckoutDialogBase</cstring>
</property>
@@ -27,7 +27,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QGroupBox">
+ <widget class="TQGroupBox">
<property name="name">
<cstring>groupBox1</cstring>
</property>
@@ -38,7 +38,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>textLabel1_2</cstring>
</property>
@@ -54,15 +54,15 @@
<cstring>workURLRequester</cstring>
</property>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout4</cstring>
+ <cstring>tqlayout4</cstring>
</property>
<grid>
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QComboBox" row="1" column="1">
+ <widget class="TQComboBox" row="1" column="1">
<property name="name">
<cstring>serverPaths</cstring>
</property>
@@ -70,7 +70,7 @@
<bool>true</bool>
</property>
</widget>
- <widget class="QLabel" row="0" column="1">
+ <widget class="TQLabel" row="0" column="1">
<property name="name">
<cstring>textLabel2</cstring>
</property>
@@ -93,7 +93,7 @@
</widget>
</vbox>
</widget>
- <widget class="QGroupBox">
+ <widget class="TQGroupBox">
<property name="name">
<cstring>groupBox2</cstring>
</property>
@@ -104,9 +104,9 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout5</cstring>
+ <cstring>tqlayout5</cstring>
</property>
<grid>
<property name="name">
@@ -122,14 +122,14 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>156</width>
<height>20</height>
</size>
</property>
</spacer>
- <widget class="QLabel" row="0" column="0">
+ <widget class="TQLabel" row="0" column="0">
<property name="name">
<cstring>textLabel1_4</cstring>
</property>
@@ -140,7 +140,7 @@
<cstring>moduleEdit</cstring>
</property>
</widget>
- <widget class="QLabel" row="0" column="2">
+ <widget class="TQLabel" row="0" column="2">
<property name="name">
<cstring>textLabel1_3</cstring>
</property>
@@ -179,7 +179,7 @@
</widget>
</grid>
</widget>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>pruneDirsCheck</cstring>
</property>
@@ -236,9 +236,9 @@
</sizepolicy>
</property>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout5</cstring>
+ <cstring>tqlayout5</cstring>
</property>
<hbox>
<property name="name">
@@ -254,14 +254,14 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>421</width>
<height>20</height>
</size>
</property>
</spacer>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>fetchModulesButton</cstring>
</property>
@@ -303,7 +303,7 @@
<tabstop>pruneDirsCheck</tabstop>
<tabstop>fetchModulesButton</tabstop>
</tabstops>
-<layoutdefaults spacing="6" margin="11"/>
+<tqlayoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>klineedit.h</includehint>
<includehint>kpushbutton.h</includehint>
diff --git a/vcs/cvsservice/commitdialogbase.ui b/vcs/cvsservice/commitdialogbase.ui
index 90e8f7b4..ee0c1ee9 100644
--- a/vcs/cvsservice/commitdialogbase.ui
+++ b/vcs/cvsservice/commitdialogbase.ui
@@ -1,6 +1,6 @@
<!DOCTYPE UI><UI version="3.1" stdsetdef="1">
<class>CommitDialogBase</class>
-<widget class="QDialog">
+<widget class="TQDialog">
<property name="name">
<cstring>CommitDialogBase</cstring>
</property>
@@ -22,7 +22,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QGroupBox">
+ <widget class="TQGroupBox">
<property name="name">
<cstring>groupBox1</cstring>
</property>
@@ -33,22 +33,22 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QTextEdit">
+ <widget class="TQTextEdit">
<property name="name">
<cstring>textEdit</cstring>
</property>
</widget>
</vbox>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout2</cstring>
+ <cstring>tqlayout2</cstring>
</property>
<hbox>
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>checkAddToChangelog</cstring>
</property>
@@ -86,9 +86,9 @@
<enum>Horizontal</enum>
</property>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout5</cstring>
+ <cstring>tqlayout5</cstring>
</property>
<hbox>
<property name="name">
@@ -104,14 +104,14 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>350</width>
<height>20</height>
</size>
</property>
</spacer>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>buttonOk</cstring>
</property>
@@ -125,7 +125,7 @@
<bool>true</bool>
</property>
</widget>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>buttonCancel</cstring>
</property>
@@ -157,5 +157,5 @@
<slot>setEnabled(bool)</slot>
</connection>
</connections>
-<layoutdefaults spacing="6" margin="11"/>
+<tqlayoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/vcs/cvsservice/commitdlg.cpp b/vcs/cvsservice/commitdlg.cpp
index a3988c06..9bed1119 100644
--- a/vcs/cvsservice/commitdlg.cpp
+++ b/vcs/cvsservice/commitdlg.cpp
@@ -30,8 +30,8 @@
///////////////////////////////////////////////////////////////////////////////
-CommitDialog::CommitDialog( const TQString &changeLogfileNamePath, TQWidget *parent )
- : CommitDialogBase( parent, "commitdialog", true )
+CommitDialog::CommitDialog( const TQString &changeLogfileNamePath, TQWidget *tqparent )
+ : CommitDialogBase( tqparent, "commitdialog", true )
{
connect( buttonOk, TQT_SIGNAL(clicked()), TQT_SLOT(accept()) );
connect( buttonCancel, TQT_SIGNAL(clicked()), TQT_SLOT(reject()) );
diff --git a/vcs/cvsservice/commitdlg.h b/vcs/cvsservice/commitdlg.h
index ffd40fae..edc27a64 100644
--- a/vcs/cvsservice/commitdlg.h
+++ b/vcs/cvsservice/commitdlg.h
@@ -24,8 +24,9 @@ class TQCheckBox;
class CommitDialog : public CommitDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- CommitDialog( const TQString &changeLogfileNamePath, TQWidget *parent = 0 );
+ CommitDialog( const TQString &changeLogfileNamePath, TQWidget *tqparent = 0 );
//! Returns the text of the log
TQStringList logMessage() const;
diff --git a/vcs/cvsservice/cvsdiffpage.cpp b/vcs/cvsservice/cvsdiffpage.cpp
index 7777760a..2f174155 100644
--- a/vcs/cvsservice/cvsdiffpage.cpp
+++ b/vcs/cvsservice/cvsdiffpage.cpp
@@ -33,10 +33,10 @@
///////////////////////////////////////////////////////////////////////////////
CVSDiffPage::CVSDiffPage( CvsService_stub *cvsService,
- TQWidget *parent, const char *name, int )
+ TQWidget *tqparent, const char *name, int )
// Leaving it anonymous let us to have multiple objects at the same time!
: DCOPObject(), // "CVSDiffPageDCOPIface"
- TQWidget( parent, name? name : "logformdialog" ),
+ TQWidget( tqparent, name? name : "logformdialog" ),
m_diffText( 0 ), m_cvsService( cvsService ), m_cvsDiffJob( 0 )
{
TQLayout *thisLayout = new TQVBoxLayout( this );
diff --git a/vcs/cvsservice/cvsdiffpage.h b/vcs/cvsservice/cvsdiffpage.h
index f38512a3..879b28b2 100644
--- a/vcs/cvsservice/cvsdiffpage.h
+++ b/vcs/cvsservice/cvsdiffpage.h
@@ -29,8 +29,9 @@ Implementation for the form displaying 'cvs diff' output.
class CVSDiffPage : public TQWidget, virtual public CVSServiceDCOPIface
{
Q_OBJECT
+ TQ_OBJECT
public:
- CVSDiffPage( CvsService_stub *cvsService, TQWidget *parent=0, const char *name=0, int flags=0 );
+ CVSDiffPage( CvsService_stub *cvsService, TQWidget *tqparent=0, const char *name=0, int flags=0 );
virtual ~CVSDiffPage();
void startDiff( const TQString &fileName, const TQString &v1, const TQString &v2 );
diff --git a/vcs/cvsservice/cvsdir.cpp b/vcs/cvsservice/cvsdir.cpp
index 28a4b566..80dabbe5 100644
--- a/vcs/cvsservice/cvsdir.cpp
+++ b/vcs/cvsservice/cvsdir.cpp
@@ -110,7 +110,7 @@ TQString CVSDir::repository() const
TQString content;
if (!isValid())
- return TQString::null;
+ return TQString();
TQByteArray bytes = cacheFile( repoFileName() );
TQTextStream t( bytes, IO_ReadOnly );
@@ -129,7 +129,7 @@ TQString CVSDir::root() const
TQString content;
if (!isValid())
- return TQString::null;
+ return TQString();
TQByteArray bytes = cacheFile( repoFileName() );
TQTextStream t( bytes, IO_ReadOnly );
@@ -173,7 +173,7 @@ TQStringList CVSDir::registeredEntryList() const
bool CVSDir::isRegistered( const TQString fileName ) const
{
- CVSEntry entry = fileStatus( fileName );
+ CVSEntry entry = filetqStatus( fileName );
return entry.isValid() && entry.fileName() == fileName;
}
@@ -197,12 +197,12 @@ void CVSDir::refreshEntriesCache() const
///////////////////////////////////////////////////////////////////////////////
-CVSEntry CVSDir::fileStatus( const TQString &fileName, bool refreshCache ) const
+CVSEntry CVSDir::filetqStatus( const TQString &fileName, bool refreshCache ) const
{
if (refreshCache)
refreshEntriesCache();
- if (m_cachedEntries.contains( fileName ))
+ if (m_cachedEntries.tqcontains( fileName ))
{
return m_cachedEntries[ fileName ];
}
@@ -284,7 +284,7 @@ void CVSDir::doNotIgnoreFile( const TQString &fileName )
///////////////////////////////////////////////////////////////////////////////
-VCSFileInfoMap CVSDir::dirStatus() const
+VCSFileInfoMap CVSDir::dirtqStatus() const
{
VCSFileInfoMap vcsInfo;
/// Convert to VCSFileInfoMap: \FIXME : any speed improvement here?
@@ -293,7 +293,7 @@ VCSFileInfoMap CVSDir::dirStatus() const
for ( ; it != end; ++it)
{
const TQString &fileName = (*it);
- const CVSEntry entry = fileStatus( fileName );
+ const CVSEntry entry = filetqStatus( fileName );
vcsInfo.insert( fileName, entry.toVCSFileInfo() );
}
@@ -303,7 +303,7 @@ VCSFileInfoMap CVSDir::dirStatus() const
///////////////////////////////////////////////////////////////////////////////
-VCSFileInfoMap *CVSDir::cacheableDirStatus() const
+VCSFileInfoMap *CVSDir::cacheableDirtqStatus() const
{
VCSFileInfoMap *vcsInfo = new VCSFileInfoMap;
/// Convert to VCSFileInfoMap: \FIXME : any speed improvement here?
@@ -312,7 +312,7 @@ VCSFileInfoMap *CVSDir::cacheableDirStatus() const
for ( ; it != end; ++it)
{
const TQString &fileName = (*it);
- const CVSEntry entry = fileStatus( fileName );
+ const CVSEntry entry = filetqStatus( fileName );
vcsInfo->insert( fileName, entry.toVCSFileInfo() );
}
diff --git a/vcs/cvsservice/cvsdir.h b/vcs/cvsservice/cvsdir.h
index bd745d3e..dc7cb53a 100644
--- a/vcs/cvsservice/cvsdir.h
+++ b/vcs/cvsservice/cvsdir.h
@@ -23,7 +23,7 @@ Helper classes for handling CVS dirs
@author Mario Scalas
*/
-class CVSDir : public QDir
+class CVSDir : public TQDir
{
public:
CVSDir();
@@ -46,11 +46,11 @@ public:
* @param refreshCache update internal cache re-parsing "<dirPath>/CVS/Entries"
* @return an empty CVSEntry if the file is not present
*/
- CVSEntry fileStatus( const TQString &fileName, bool refreshCache = false ) const;
+ CVSEntry filetqStatus( const TQString &fileName, bool refreshCache = false ) const;
/**
*/
- VCSFileInfoMap dirStatus() const;
- VCSFileInfoMap *cacheableDirStatus() const;
+ VCSFileInfoMap dirtqStatus() const;
+ VCSFileInfoMap *cacheableDirtqStatus() const;
/**
* @return true if the file is registered into repository, false otherwise
*/
diff --git a/vcs/cvsservice/cvsentry.cpp b/vcs/cvsservice/cvsentry.cpp
index 5db9710e..eb8ca704 100644
--- a/vcs/cvsservice/cvsentry.cpp
+++ b/vcs/cvsservice/cvsentry.cpp
@@ -91,7 +91,7 @@ void CVSEntry::parse( const TQString &aLine, const CVSDir& dir )
m_state = Added;
else if ( revision().length() > 3 && revision()[0] == '-' )
m_state = Removed;
- else if ( timeStamp().find('+') >= 0 )
+ else if ( timeStamp().tqfind('+') >= 0 )
m_state = Conflict;
else
{
@@ -110,7 +110,7 @@ TQString CVSEntry::fileName() const
if (type() != invalidEntry && m_fields.count() >= 1)
return m_fields[0];
else
- return TQString::null;
+ return TQString();
}
///////////////////////////////////////////////////////////////////////////////
@@ -120,7 +120,7 @@ TQString CVSEntry::revision() const
if (type() != invalidEntry && m_fields.count() >= 2)
return m_fields[1];
else
- return TQString::null;
+ return TQString();
}
///////////////////////////////////////////////////////////////////////////////
@@ -130,7 +130,7 @@ TQString CVSEntry::timeStamp() const
if (type() != invalidEntry && m_fields.count() >= 3)
return m_fields[2];
else
- return TQString::null;
+ return TQString();
}
///////////////////////////////////////////////////////////////////////////////
@@ -140,7 +140,7 @@ TQString CVSEntry::options() const
if (type() != invalidEntry && m_fields.count() >= 4)
return m_fields[3];
else
- return TQString::null;
+ return TQString();
}
///////////////////////////////////////////////////////////////////////////////
@@ -150,7 +150,7 @@ TQString CVSEntry::tag() const
if (type() != invalidEntry && m_fields.count() >= 5)
return m_fields[4];
else
- return TQString::null;
+ return TQString();
}
///////////////////////////////////////////////////////////////////////////////
@@ -184,4 +184,4 @@ VCSFileInfo CVSEntry::toVCSFileInfo() const
return VCSFileInfo( fileName(), revision(), revision(), fileState );
}
-//kate: space-indent on; indent-width 4; replace-tabs on;
+//kate: space-indent on; indent-width 4; tqreplace-tabs on;
diff --git a/vcs/cvsservice/cvsfileinfoprovider.h b/vcs/cvsservice/cvsfileinfoprovider.h
index 9b80dc8e..72f3cff0 100644
--- a/vcs/cvsservice/cvsfileinfoprovider.h
+++ b/vcs/cvsservice/cvsfileinfoprovider.h
@@ -31,15 +31,16 @@ Provider for CVS file information
class CVSFileInfoProvider : public KDevVCSFileInfoProvider, virtual public CVSServiceDCOPIface
{
Q_OBJECT
+ TQ_OBJECT
public:
- CVSFileInfoProvider( CvsServicePart *parent, CvsService_stub *cvsService );
+ CVSFileInfoProvider( CvsServicePart *tqparent, CvsService_stub *cvsService );
virtual ~CVSFileInfoProvider();
// -- Sync interface
virtual const VCSFileInfoMap *status( const TQString &dirPath ) ;
// -- Async interface for requesting data
- virtual bool requestStatus( const TQString &dirPath, void *callerData, bool recursive = true, bool checkRepos = true );
+ virtual bool requesttqStatus( const TQString &dirPath, void *callerData, bool recursive = true, bool checkRepos = true );
public slots:
void updateStatusFor( const CVSDir& );
diff --git a/vcs/cvsservice/cvsform.cpp b/vcs/cvsservice/cvsform.cpp
index ef0521c8..e1423ef6 100644
--- a/vcs/cvsservice/cvsform.cpp
+++ b/vcs/cvsservice/cvsform.cpp
@@ -19,8 +19,8 @@
// class CvsForm
///////////////////////////////////////////////////////////////////////////////
-CvsForm::CvsForm( TQWidget *parent, const char *name, WFlags f )
- : CvsFormBase( parent, name, f )
+CvsForm::CvsForm( TQWidget *tqparent, const char *name, WFlags f )
+ : CvsFormBase( tqparent, name, f )
{
setWFlags( getWFlags() | WDestructiveClose );
}
diff --git a/vcs/cvsservice/cvsform.h b/vcs/cvsservice/cvsform.h
index a61e8473..8a9a4ef7 100644
--- a/vcs/cvsservice/cvsform.h
+++ b/vcs/cvsservice/cvsform.h
@@ -21,8 +21,9 @@ information about setting up the cvs repository.
class CvsForm : public CvsFormBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- CvsForm( TQWidget *parent = 0, const char *name = 0, WFlags f = 0 );
+ CvsForm( TQWidget *tqparent = 0, const char *name = 0, WFlags f = 0 );
virtual ~CvsForm();
TQString module() const;
diff --git a/vcs/cvsservice/cvsformbase.ui b/vcs/cvsservice/cvsformbase.ui
index 2a7b5c42..acd4d3bf 100644
--- a/vcs/cvsservice/cvsformbase.ui
+++ b/vcs/cvsservice/cvsformbase.ui
@@ -1,7 +1,7 @@
<!DOCTYPE UI><UI version="3.1" stdsetdef="1">
<class>CvsFormBase</class>
<author>Yann Hodique</author>
-<widget class="QWidget">
+<widget class="TQWidget">
<property name="name">
<cstring>CvsFormBase</cstring>
</property>
@@ -20,7 +20,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel" row="5" column="0">
+ <widget class="TQLabel" row="5" column="0">
<property name="name">
<cstring>TextLabel5</cstring>
</property>
@@ -60,7 +60,7 @@ Most of the thime you'll just reuse the project name</string>
<string>Enter the vendor name</string>
</property>
</widget>
- <widget class="QLabel" row="4" column="0">
+ <widget class="TQLabel" row="4" column="0">
<property name="name">
<cstring>TextLabel3</cstring>
</property>
@@ -71,7 +71,7 @@ Most of the thime you'll just reuse the project name</string>
<cstring>message_edit</cstring>
</property>
</widget>
- <widget class="QLabel" row="2" column="0">
+ <widget class="TQLabel" row="2" column="0">
<property name="name">
<cstring>TextLabel2</cstring>
</property>
@@ -82,7 +82,7 @@ Most of the thime you'll just reuse the project name</string>
<cstring>module_edit</cstring>
</property>
</widget>
- <widget class="QLabel" row="3" column="0">
+ <widget class="TQLabel" row="3" column="0">
<property name="name">
<cstring>TextLabel4</cstring>
</property>
@@ -115,7 +115,7 @@ Most of the thime you'll just reuse the project name</string>
<string>Tag that will be associated with initial state</string>
</property>
</widget>
- <widget class="QLabel" row="0" column="0">
+ <widget class="TQLabel" row="0" column="0">
<property name="name">
<cstring>TextLabel1</cstring>
</property>
@@ -144,7 +144,7 @@ Most of the thime you'll just reuse the project name</string>
&lt;li&gt;/home/cvsroot or&lt;/li&gt;&lt;li&gt;:pserver:me@localhost:/home/cvs&lt;/li&gt;&lt;/ul&gt;</string>
</property>
</widget>
- <widget class="QLabel" row="1" column="0">
+ <widget class="TQLabel" row="1" column="0">
<property name="name">
<cstring>TextLabel1_2</cstring>
</property>
@@ -161,7 +161,7 @@ Most of the thime you'll just reuse the project name</string>
<cstring>cvsRshComboBox</cstring>
</property>
</widget>
- <widget class="QComboBox" row="1" column="1">
+ <widget class="TQComboBox" row="1" column="1">
<item>
<property name="text">
<string></string>
@@ -176,7 +176,7 @@ Most of the thime you'll just reuse the project name</string>
<cstring>cvsRshComboBox</cstring>
</property>
</widget>
- <widget class="QCheckBox" row="1" column="3">
+ <widget class="TQCheckBox" row="1" column="3">
<property name="name">
<cstring>init_check</cstring>
</property>
@@ -197,7 +197,7 @@ Most of the thime you'll just reuse the project name</string>
<property name="sizeType">
<enum>Preferred</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>51</width>
<height>20</height>
@@ -218,6 +218,6 @@ Most of the thime you'll just reuse the project name</string>
<includes>
<include location="global" impldecl="in implementation">kdialog.h</include>
</includes>
-<layoutdefaults spacing="6" margin="11"/>
-<layoutfunctions spacing="KDialog::spacingHint" margin="KDialog::marginHint"/>
+<tqlayoutdefaults spacing="6" margin="11"/>
+<tqlayoutfunctions spacing="KDialog::spacingHint" margin="KDialog::marginHint"/>
</UI>
diff --git a/vcs/cvsservice/cvslogdialog.cpp b/vcs/cvsservice/cvslogdialog.cpp
index ff36c19d..5bd230c3 100644
--- a/vcs/cvsservice/cvslogdialog.cpp
+++ b/vcs/cvsservice/cvslogdialog.cpp
@@ -32,9 +32,9 @@
// class CVSLogDialog
///////////////////////////////////////////////////////////////////////////////
-CVSLogDialog::CVSLogDialog( CvsService_stub *cvsService, TQWidget *parent, const char *name, int )
+CVSLogDialog::CVSLogDialog( CvsService_stub *cvsService, TQWidget *tqparent, const char *name, int )
: KDialogBase( Tabbed, i18n("CVS Log & Diff Dialog"), Close, Close,
- parent, name? name : "logformdialog", false /*modal*/, true /*separator*/ ),
+ tqparent, name? name : "logformdialog", false /*modal*/, true /*separator*/ ),
m_cvsLogPage( 0 ), m_cvsService( cvsService )
{
setWFlags( getWFlags() | WDestructiveClose );
@@ -79,7 +79,7 @@ void CVSLogDialog::slotDiffRequested( const TQString &pathName, const TQString &
kdDebug(9006) << "CVSLogDialog::slotDiffRequested()" << endl;
// Create a new CVSDiffPage and start diffing process
- TQString diffTitle = i18n("Diff between %1 and %2").arg( revA ).arg( revB );
+ TQString diffTitle = i18n("Diff between %1 and %2").tqarg( revA ).tqarg( revB );
TQVBox *vbox = addVBoxPage( diffTitle );
CVSDiffPage *diffPage = new CVSDiffPage( m_cvsService, vbox );
diffPage->startDiff( pathName, revA, revB );
diff --git a/vcs/cvsservice/cvslogdialog.h b/vcs/cvsservice/cvslogdialog.h
index 315fea40..9f3518aa 100644
--- a/vcs/cvsservice/cvslogdialog.h
+++ b/vcs/cvsservice/cvslogdialog.h
@@ -26,8 +26,9 @@ Implementation for the form displaying 'cvs log' output.
class CVSLogDialog : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- CVSLogDialog( CvsService_stub *cvsService, TQWidget *parent=0, const char *name=0, int flags=0 );
+ CVSLogDialog( CvsService_stub *cvsService, TQWidget *tqparent=0, const char *name=0, int flags=0 );
virtual ~CVSLogDialog();
void startLog( const TQString &workDir, const TQString &pathName );
diff --git a/vcs/cvsservice/cvslogpage.cpp b/vcs/cvsservice/cvslogpage.cpp
index c0ade68e..1f4b925e 100644
--- a/vcs/cvsservice/cvslogpage.cpp
+++ b/vcs/cvsservice/cvslogpage.cpp
@@ -32,9 +32,9 @@
// class CVSLogPage
///////////////////////////////////////////////////////////////////////////////
-CVSLogPage::CVSLogPage( CvsService_stub *cvsService, TQWidget *parent, const char *name, int )
+CVSLogPage::CVSLogPage( CvsService_stub *cvsService, TQWidget *tqparent, const char *name, int )
: DCOPObject( "CvsLogPageDCOPIface" ),
- TQWidget( parent, name? name : "logformpage" ),
+ TQWidget( tqparent, name? name : "logformpage" ),
m_cvsService( cvsService ), m_cvsLogJob( 0 )
{
TQLayout *thisLayout = new TQVBoxLayout( this );
@@ -113,7 +113,7 @@ void CVSLogPage::slotJobExited( bool normalExit, int exitStatus )
// m_part->core()->running( m_part, false );
if (!normalExit)
{
- KMessageBox::sorry( this, i18n("Log failed with exitStatus == %1").arg( exitStatus), i18n("Log Failed") );
+ KMessageBox::sorry( this, i18n("Log failed with exitStatus == %1").tqarg( exitStatus), i18n("Log Failed") );
return;
}
@@ -133,7 +133,7 @@ void CVSLogPage::slotJobExited( bool normalExit, int exitStatus )
TQString dstr = "<b>" + s + "</b> ";
int lastVer = ver.section( '.', -1 ).toInt() - 1;
if ( lastVer > 0 ) {
- TQString lv = ver.left( ver.findRev( "." ) + 1 ) + TQString::number( lastVer );
+ TQString lv = ver.left( ver.tqfindRev( "." ) + 1 ) + TQString::number( lastVer );
dstr += " [<a href=\"diff:/" + m_pathName + "/" + lv + "_" + ver + "\">diff to " + lv + "</a>]";
}
m_textBrowser->setTextFormat( TQTextBrowser::RichText );
@@ -172,7 +172,7 @@ void CVSLogPage::slotLinkClicked( const TQString &link )
/// \FIXME in this way I lose the source
m_textBrowser->setSource( m_logTextBackup );
- TQString ver = link.mid( link.findRev( "/" ) + 1 );
+ TQString ver = link.mid( link.tqfindRev( "/" ) + 1 );
TQString v1 = ver.section( '_', 0, 0 );
TQString v2 = ver.section( '_', 1, 1 );
if ( v1.isEmpty() || v2.isEmpty() )
diff --git a/vcs/cvsservice/cvslogpage.h b/vcs/cvsservice/cvslogpage.h
index c4f27ee8..27fbd3d2 100644
--- a/vcs/cvsservice/cvslogpage.h
+++ b/vcs/cvsservice/cvslogpage.h
@@ -28,8 +28,9 @@ Implementation for the form displaying 'cvs log' output.
class CVSLogPage : public TQWidget, virtual public CVSServiceDCOPIface
{
Q_OBJECT
+ TQ_OBJECT
public:
- CVSLogPage( CvsService_stub *cvsService, TQWidget *parent=0, const char *name=0, int flags=0 );
+ CVSLogPage( CvsService_stub *cvsService, TQWidget *tqparent=0, const char *name=0, int flags=0 );
virtual ~CVSLogPage();
void startLog( const TQString &workDir, const TQString &pathName );
diff --git a/vcs/cvsservice/cvsoptions.cpp b/vcs/cvsservice/cvsoptions.cpp
index 43add3be..6f2894e6 100644
--- a/vcs/cvsservice/cvsoptions.cpp
+++ b/vcs/cvsservice/cvsoptions.cpp
@@ -24,9 +24,9 @@
// Macros
///////////////////////////////////////////////////////////////////////////////
-#define default_revert TQString::fromLatin1("-C")
-#define default_diff TQString::fromLatin1("-p")
-#define default_rsh TQString::fromLatin1("")
+#define default_revert TQString::tqfromLatin1("-C")
+#define default_diff TQString::tqfromLatin1("-p")
+#define default_rsh TQString::tqfromLatin1("")
#define default_contextLines 3
#define default_compression 0
diff --git a/vcs/cvsservice/cvsoptionswidget.cpp b/vcs/cvsservice/cvsoptionswidget.cpp
index 32044dd3..eb66b773 100644
--- a/vcs/cvsservice/cvsoptionswidget.cpp
+++ b/vcs/cvsservice/cvsoptionswidget.cpp
@@ -24,8 +24,8 @@
// class DiffDialog
///////////////////////////////////////////////////////////////////////////////
-CvsOptionsWidget::CvsOptionsWidget( TQWidget *parent, const char *name )
- : CvsOptionsWidgetBase( parent, name )
+CvsOptionsWidget::CvsOptionsWidget( TQWidget *tqparent, const char *name )
+ : CvsOptionsWidgetBase( tqparent, name )
{
readConfig();
}
diff --git a/vcs/cvsservice/cvsoptionswidget.h b/vcs/cvsservice/cvsoptionswidget.h
index 49039749..0dcfbba0 100644
--- a/vcs/cvsservice/cvsoptionswidget.h
+++ b/vcs/cvsservice/cvsoptionswidget.h
@@ -23,8 +23,9 @@ class TQVBoxLayout;
class CvsOptionsWidget : public CvsOptionsWidgetBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- CvsOptionsWidget( TQWidget *parent, const char *name=0 );
+ CvsOptionsWidget( TQWidget *tqparent, const char *name=0 );
virtual ~CvsOptionsWidget();
bool pruneEmptyDirWhenUpdating() const;
diff --git a/vcs/cvsservice/cvsoptionswidgetbase.ui b/vcs/cvsservice/cvsoptionswidgetbase.ui
index 4938ea4a..36cff3cd 100644
--- a/vcs/cvsservice/cvsoptionswidgetbase.ui
+++ b/vcs/cvsservice/cvsoptionswidgetbase.ui
@@ -1,6 +1,6 @@
<!DOCTYPE UI><UI version="3.1" stdsetdef="1">
<class>CvsOptionsWidgetBase</class>
-<widget class="QWidget">
+<widget class="TQWidget">
<property name="name">
<cstring>cvsOptionsWidget</cstring>
</property>
@@ -19,7 +19,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QGroupBox">
+ <widget class="TQGroupBox">
<property name="name">
<cstring>groupBox4</cstring>
</property>
@@ -30,7 +30,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>m_rshLabel</cstring>
</property>
@@ -60,7 +60,7 @@
<string>Set this option to "ssh" to use ssh as remote shell for CVS. Note that you need password-less login (see the ssh documentation for how to generate a public/private key pair) otherwise CVS will just hang forever.</string>
</property>
</widget>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>textLabel1_2</cstring>
</property>
@@ -78,7 +78,7 @@
</widget>
</vbox>
</widget>
- <widget class="QGroupBox">
+ <widget class="TQGroupBox">
<property name="name">
<cstring>groupBox1</cstring>
</property>
@@ -89,7 +89,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>createNewDirWhenUpdateCheck</cstring>
</property>
@@ -97,7 +97,7 @@
<string>Create &amp;new directories (if any)</string>
</property>
</widget>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>pruneEmptyDirWhenUpdateCheck</cstring>
</property>
@@ -105,7 +105,7 @@
<string>&amp;Prune empty directories</string>
</property>
</widget>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>recursiveWhenUpdateCheck</cstring>
</property>
@@ -115,7 +115,7 @@
</widget>
</vbox>
</widget>
- <widget class="QGroupBox">
+ <widget class="TQGroupBox">
<property name="name">
<cstring>groupBox2</cstring>
</property>
@@ -126,7 +126,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>recursiveWhenCommitRemoveCheck</cstring>
</property>
@@ -136,7 +136,7 @@
</widget>
</vbox>
</widget>
- <widget class="QGroupBox">
+ <widget class="TQGroupBox">
<property name="name">
<cstring>groupBox3</cstring>
</property>
@@ -160,7 +160,7 @@
</sizepolicy>
</property>
</widget>
- <widget class="QLabel" row="0" column="0">
+ <widget class="TQLabel" row="0" column="0">
<property name="name">
<cstring>m_diffLabel</cstring>
</property>
@@ -193,7 +193,7 @@
<number>65535</number>
</property>
</widget>
- <widget class="QLabel" row="0" column="1">
+ <widget class="TQLabel" row="0" column="1">
<property name="name">
<cstring>textLabel1</cstring>
</property>
@@ -221,8 +221,8 @@
<includes>
<include location="global" impldecl="in implementation">kdialog.h</include>
</includes>
-<layoutdefaults spacing="6" margin="11"/>
-<layoutfunctions spacing="KDialog::spacingHint" margin="KDialog::marginHint"/>
+<tqlayoutdefaults spacing="6" margin="11"/>
+<tqlayoutfunctions spacing="KDialog::spacingHint" margin="KDialog::marginHint"/>
<includehints>
<includehint>knuminput.h</includehint>
<includehint>knuminput.h</includehint>
diff --git a/vcs/cvsservice/cvspartimpl.cpp b/vcs/cvsservice/cvspartimpl.cpp
index ca66e610..f038ac56 100644
--- a/vcs/cvsservice/cvspartimpl.cpp
+++ b/vcs/cvsservice/cvspartimpl.cpp
@@ -211,7 +211,7 @@ bool CvsServicePartImpl::isRegisteredInRepository( const TQString &projectDirect
kdDebug(9006) << k_funcinfo << " Error: " << cvsdir.path() << " is not a valid CVS directory " << endl;
return false;
}
- CVSEntry entry = cvsdir.fileStatus( url.fileName() );
+ CVSEntry entry = cvsdir.filetqStatus( url.fileName() );
return entry.isValid();
}
}
@@ -318,7 +318,7 @@ KDevMainWindow *CvsServicePartImpl::mainWindow() const
TQString CvsServicePartImpl::projectDirectory() const
{
- return m_part->project() ? m_part->project()->projectDirectory() : TQString::null;
+ return m_part->project() ? m_part->project()->projectDirectory() : TQString();
}
///////////////////////////////////////////////////////////////////////////////
@@ -639,7 +639,7 @@ void CvsServicePartImpl::diff( const KURL::List& urlList )
return;
CVSDir cvsdir = CVSDir( urlList[0].directory() );
- CVSEntry entry = cvsdir.fileStatus( urlList[0].fileName() );
+ CVSEntry entry = cvsdir.filetqStatus( urlList[0].fileName() );
DiffDialog dlg(entry);
if (dlg.exec() != TQDialog::Accepted)
@@ -971,7 +971,7 @@ void CvsServicePartImpl::slotCheckoutFinished( bool exitStatus, int )
<< exitStatus << endl;
// Return a null string if the operation was not succesfull
if (!exitStatus)
- modulePath = TQString::null;
+ modulePath = TQString();
kdDebug(9006) << " I'll emit modulePath == " << modulePath << endl;
diff --git a/vcs/cvsservice/cvspartimpl.h b/vcs/cvsservice/cvspartimpl.h
index 93da0ec3..18f791fd 100644
--- a/vcs/cvsservice/cvspartimpl.h
+++ b/vcs/cvsservice/cvspartimpl.h
@@ -41,11 +41,12 @@ class CVSFileInfoProvider;
*
* @author Mario Scalas
*/
-class CvsServicePartImpl : public QObject
+class CvsServicePartImpl : public TQObject
{
friend class CvsServicePart;
Q_OBJECT
+ TQ_OBJECT
public:
//! Available Cvs operations
enum CvsOperation
diff --git a/vcs/cvsservice/cvsprocesswidget.cpp b/vcs/cvsservice/cvsprocesswidget.cpp
index d2e78da6..550b76b5 100644
--- a/vcs/cvsservice/cvsprocesswidget.cpp
+++ b/vcs/cvsservice/cvsprocesswidget.cpp
@@ -43,13 +43,13 @@ int g_dcopErrCounter = 0;
#endif
-CvsProcessWidget::CvsProcessWidget( CvsService_stub *service, CvsServicePart *part, TQWidget *parent, const char *name )
+CvsProcessWidget::CvsProcessWidget( CvsService_stub *service, CvsServicePart *part, TQWidget *tqparent, const char *name )
: DCOPObject( "CvsProcessWidgetDCOPIface" ),
- TQTextEdit( parent, name ),
+ TQTextEdit( tqparent, name ),
m_part( part ), m_service( service ), m_job( 0 )
{
setReadOnly( true );
- setTextFormat( Qt::LogText );
+ setTextFormat( TQt::LogText );
TQStyleSheetItem *style = 0;
style = new TQStyleSheetItem( styleSheet(), "goodtag" );
@@ -106,8 +106,8 @@ bool CvsProcessWidget::isAlreadyWorking() const
void CvsProcessWidget::clear()
{
TQTextEdit::clear();
- this->m_errors = TQString::null;
- this->m_output = TQString::null;
+ this->m_errors = TQString();
+ this->m_output = TQString();
}
///////////////////////////////////////////////////////////////////////////////
@@ -142,7 +142,7 @@ bool CvsProcessWidget::startJob( const DCOPRef &aJob )
// disconnect 3rd party slots from our signals
disconnect( TQT_SIGNAL(jobFinished(bool, int)) );
- showInfo( i18n("Started job: %1").arg( cmdLine ) );
+ showInfo( i18n("Started job: %1").tqarg( cmdLine ) );
#ifdef MYDCOPDEBUG
g_dcopExitCounter = 0;
@@ -187,7 +187,7 @@ void CvsProcessWidget::slotJobExited( bool normalExit, int exitStatus )
m_job = 0;
}
TQString exitMsg = i18n("Job finished with exitCode == %1");
- showInfo( exitMsg.arg( exitStatus) );
+ showInfo( exitMsg.tqarg( exitStatus) );
m_part->core()->running( m_part, false );
m_part->mainWindow()->statusBar()->message( i18n("Done CVS command ..."), 2000 );
@@ -264,9 +264,9 @@ void CvsProcessWidget::showOutput( const TQStringList &msg )
//This will prevent TQTextEdit from crashing on trying to parse the tags.
//This should fix BUG:99590
TQString lineNew(line);
- lineNew.replace("<", "&lt;");
- lineNew.replace(">", "&gt;");
- lineNew.replace("&", "&amp;");
+ lineNew.tqreplace("<", "&lt;");
+ lineNew.tqreplace(">", "&gt;");
+ lineNew.tqreplace("&", "&amp;");
if (line.startsWith( "C " ))
append( "<cvs_conflict>" + lineNew + "</cvs_conflict>" );
diff --git a/vcs/cvsservice/cvsprocesswidget.h b/vcs/cvsservice/cvsprocesswidget.h
index 81e34f04..2377ee97 100644
--- a/vcs/cvsservice/cvsprocesswidget.h
+++ b/vcs/cvsservice/cvsprocesswidget.h
@@ -27,9 +27,10 @@ class TQStyleSheetItem;
class CvsProcessWidget : public TQTextEdit, virtual public CVSServiceDCOPIface
{
Q_OBJECT
+ TQ_OBJECT
public:
CvsProcessWidget( CvsService_stub *service, CvsServicePart *part,
- TQWidget *parent, const char *name );
+ TQWidget *tqparent, const char *name );
virtual ~CvsProcessWidget();
bool startJob( const DCOPRef &aJob );
diff --git a/vcs/cvsservice/diffdialog.cpp b/vcs/cvsservice/diffdialog.cpp
index 9d592c8b..fd4ca8ef 100644
--- a/vcs/cvsservice/diffdialog.cpp
+++ b/vcs/cvsservice/diffdialog.cpp
@@ -20,8 +20,8 @@
// class DiffDialog
///////////////////////////////////////////////////////////////////////////////
-DiffDialog::DiffDialog( const CVSEntry &entry, TQWidget *parent, const char *name, WFlags f )
- : DiffDialogBase( parent, name, true, f)
+DiffDialog::DiffDialog( const CVSEntry &entry, TQWidget *tqparent, const char *name, WFlags f )
+ : DiffDialogBase( tqparent, name, true, f)
{
m_entry = entry;
TQString currentRevision = entry.revision();
@@ -62,7 +62,7 @@ TQString DiffDialog::revA() const
else if (requestedDiff() == diffLocalHEAD)
return "HEAD";
else
- return TQString::null;
+ return TQString();
}
///////////////////////////////////////////////////////////////////////////////
@@ -72,7 +72,7 @@ TQString DiffDialog::revB() const
if (requestedDiff())
return this->revbEdit->text();
else
- return TQString::null;
+ return TQString();
}
///////////////////////////////////////////////////////////////////////////////
@@ -83,7 +83,7 @@ void DiffDialog::languageChange() {
//FIXME: We need a function in CVSEntry to return the latest revision there is in cvs
// if(!m_entry.revision().isNull())
-// diffLocalHeadRadio->setText( tr2i18n( "Local copy and &HEAD (%1)" ).arg( m_entry.revision()) );
+// diffLocalHeadRadio->setText( tr2i18n( "Local copy and &HEAD (%1)" ).tqarg( m_entry.revision()) );
}
#include "diffdialog.moc"
diff --git a/vcs/cvsservice/diffdialog.h b/vcs/cvsservice/diffdialog.h
index 3caa66cf..8870ff1e 100644
--- a/vcs/cvsservice/diffdialog.h
+++ b/vcs/cvsservice/diffdialog.h
@@ -23,8 +23,9 @@
class DiffDialog : public DiffDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- DiffDialog(const CVSEntry &entry, TQWidget *parent = 0, const char *name = 0, WFlags f = 0 );
+ DiffDialog(const CVSEntry &entry, TQWidget *tqparent = 0, const char *name = 0, WFlags f = 0 );
virtual ~DiffDialog();
TQString revA() const;
diff --git a/vcs/cvsservice/diffdialogbase.ui b/vcs/cvsservice/diffdialogbase.ui
index 0290c530..d04a9a68 100644
--- a/vcs/cvsservice/diffdialogbase.ui
+++ b/vcs/cvsservice/diffdialogbase.ui
@@ -1,6 +1,6 @@
<!DOCTYPE UI><UI version="3.3" stdsetdef="1">
<class>DiffDialogBase</class>
-<widget class="QDialog">
+<widget class="TQDialog">
<property name="name">
<cstring>DiffDialog</cstring>
</property>
@@ -22,7 +22,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QButtonGroup">
+ <widget class="TQButtonGroup">
<property name="name">
<cstring>buttonGroup1</cstring>
</property>
@@ -33,15 +33,15 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLayoutWidget" row="2" column="0">
+ <widget class="TQLayoutWidget" row="2" column="0">
<property name="name">
- <cstring>layout3</cstring>
+ <cstring>tqlayout3</cstring>
</property>
<hbox>
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QRadioButton">
+ <widget class="TQRadioButton">
<property name="name">
<cstring>diffLocalOtherRadio</cstring>
</property>
@@ -59,7 +59,7 @@
</widget>
</hbox>
</widget>
- <widget class="QRadioButton" row="3" column="0">
+ <widget class="TQRadioButton" row="3" column="0">
<property name="name">
<cstring>diffArbitraryRevRadio</cstring>
</property>
@@ -67,15 +67,15 @@
<string>&amp;Two arbitrary revisions/tags:</string>
</property>
</widget>
- <widget class="QLayoutWidget" row="4" column="0">
+ <widget class="TQLayoutWidget" row="4" column="0">
<property name="name">
- <cstring>layout3</cstring>
+ <cstring>tqlayout3</cstring>
</property>
<grid>
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel" row="0" column="0">
+ <widget class="TQLabel" row="0" column="0">
<property name="name">
<cstring>textLabel1</cstring>
</property>
@@ -116,7 +116,7 @@
<string>First revision to compare</string>
</property>
</widget>
- <widget class="QLabel" row="0" column="1">
+ <widget class="TQLabel" row="0" column="1">
<property name="name">
<cstring>textLabel2</cstring>
</property>
@@ -134,7 +134,7 @@
</widget>
</grid>
</widget>
- <widget class="QRadioButton" row="1" column="0">
+ <widget class="TQRadioButton" row="1" column="0">
<property name="name">
<cstring>diffLocalHeadRadio</cstring>
</property>
@@ -142,7 +142,7 @@
<string>Local cop&amp;y and HEAD</string>
</property>
</widget>
- <widget class="QRadioButton" row="0" column="0">
+ <widget class="TQRadioButton" row="0" column="0">
<property name="name">
<cstring>diffLocalBaseRadio</cstring>
</property>
@@ -169,9 +169,9 @@
<enum>Horizontal</enum>
</property>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout2</cstring>
+ <cstring>tqlayout2</cstring>
</property>
<hbox>
<property name="name">
@@ -187,14 +187,14 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>130</width>
<height>20</height>
</size>
</property>
</spacer>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>buttonOk</cstring>
</property>
@@ -211,7 +211,7 @@
<bool>true</bool>
</property>
</widget>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>buttonCancel</cstring>
</property>
@@ -271,5 +271,5 @@
<tabstop>buttonOk</tabstop>
<tabstop>buttonCancel</tabstop>
</tabstops>
-<layoutdefaults spacing="6" margin="11"/>
+<tqlayoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/vcs/cvsservice/diffwidget.cpp b/vcs/cvsservice/diffwidget.cpp
index 87f8494f..8c5c53c6 100644
--- a/vcs/cvsservice/diffwidget.cpp
+++ b/vcs/cvsservice/diffwidget.cpp
@@ -39,7 +39,7 @@ static const int POPUP_BASE = 130977;
TQStringList KDiffTextEdit::extParts;
TQStringList KDiffTextEdit::extPartsTranslated;
-KDiffTextEdit::KDiffTextEdit( TQWidget* parent, const char* name ): TQTextEdit( parent, name )
+KDiffTextEdit::KDiffTextEdit( TQWidget* tqparent, const char* name ): TQTextEdit( tqparent, name )
{
KConfig* config = kapp->config();
config->setGroup( "Diff" );
@@ -70,7 +70,7 @@ TQPopupMenu* KDiffTextEdit::createPopupMenu( const TQPoint& p )
int i = 0;
for ( TQStringList::Iterator it = extPartsTranslated.begin(); it != extPartsTranslated.end(); ++it ) {
- popup->insertItem( i18n( "Show in %1" ).arg( *it ), i + POPUP_BASE, i );
+ popup->insertItem( i18n( "Show in %1" ).tqarg( *it ), i + POPUP_BASE, i );
i++;
}
if ( !extPartsTranslated.isEmpty() )
@@ -174,8 +174,8 @@ void KDiffTextEdit::popupActivated( int id )
emit externalPartRequested( extParts[ id ] );
}
-DiffWidget::DiffWidget( TQWidget *parent, const char *name, WFlags f ):
- TQWidget( parent, name, f ), tempFile( 0 )
+DiffWidget::DiffWidget( TQWidget *tqparent, const char *name, WFlags f ):
+ TQWidget( tqparent, name, f ), tempFile( 0 )
{
job = 0;
extPart = 0;
@@ -186,8 +186,8 @@ DiffWidget::DiffWidget( TQWidget *parent, const char *name, WFlags f ):
// te->setMinimumSize( 300, 200 );
connect( te, TQT_SIGNAL(externalPartRequested(const TQString&)), this, TQT_SLOT(loadExtPart(const TQString&)) );
- TQVBoxLayout* layout = new TQVBoxLayout( this );
- layout->addWidget( te );
+ TQVBoxLayout* tqlayout = new TQVBoxLayout( this );
+ tqlayout->addWidget( te );
}
DiffWidget::~DiffWidget()
@@ -222,11 +222,11 @@ void DiffWidget::loadExtPart( const TQString& partName )
if ( !extService )
return;
- extPart = KParts::ComponentFactory::createPartInstanceFromService<KParts::ReadOnlyPart>( extService, this, 0, this, 0 );
+ extPart = KParts::ComponentFactory::createPartInstanceFromService<KParts::ReadOnlyPart>( extService, this, 0, TQT_TQOBJECT(this), 0 );
if ( !extPart || !extPart->widget() )
return;
- layout()->add( extPart->widget() );
+ tqlayout()->add( extPart->widget() );
setExtPartVisible( true );
diff --git a/vcs/cvsservice/diffwidget.h b/vcs/cvsservice/diffwidget.h
index 37bed7ea..48b6447d 100644
--- a/vcs/cvsservice/diffwidget.h
+++ b/vcs/cvsservice/diffwidget.h
@@ -29,11 +29,12 @@ namespace KParts {
}
// Helper class that displays a modified RMB popup menu
-class KDiffTextEdit: public QTextEdit
+class KDiffTextEdit: public TQTextEdit
{
Q_OBJECT
+ TQ_OBJECT
public:
- KDiffTextEdit( TQWidget* parent = 0, const char* name = 0 );
+ KDiffTextEdit( TQWidget* tqparent = 0, const char* name = 0 );
virtual ~KDiffTextEdit();
void applySyntaxHighlight();
void clearSyntaxHighlight();
@@ -57,12 +58,13 @@ private:
bool _highlight;
};
-class DiffWidget : public QWidget
+class DiffWidget : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
- DiffWidget( TQWidget *parent = 0, const char *name = 0, WFlags f = 0 );
+ DiffWidget( TQWidget *tqparent = 0, const char *name = 0, WFlags f = 0 );
virtual ~DiffWidget();
public slots:
diff --git a/vcs/cvsservice/editorsdialog.cpp b/vcs/cvsservice/editorsdialog.cpp
index 5f26d100..9b796254 100644
--- a/vcs/cvsservice/editorsdialog.cpp
+++ b/vcs/cvsservice/editorsdialog.cpp
@@ -24,8 +24,8 @@
#include <cvsjob_stub.h>
#include <cvsservice_stub.h>
-EditorsDialog::EditorsDialog(CvsService_stub *cvsService, TQWidget *parent, const char *name)
- : DCOPObject( "CvsEditorsDCOPIface"), EditorsDialogBase(parent, name, TRUE, Qt::WDestructiveClose),
+EditorsDialog::EditorsDialog(CvsService_stub *cvsService, TQWidget *tqparent, const char *name)
+ : DCOPObject( "CvsEditorsDCOPIface"), EditorsDialogBase(tqparent, name, TRUE, TQt::WDestructiveClose),
m_cvsService(cvsService), m_cvsJob(0)
{
}
@@ -61,7 +61,7 @@ void EditorsDialog::slotJobExited( bool normalExit, int exitStatus )
{
if (!normalExit)
{
- KMessageBox::sorry( this, i18n("Log failed with exitStatus == %1").arg( exitStatus), i18n("Log Failed") );
+ KMessageBox::sorry( this, i18n("Log failed with exitStatus == %1").tqarg( exitStatus), i18n("Log Failed") );
return;
}
@@ -121,7 +121,7 @@ void EditorsDialog::slotReceivedOutput( TQString someOutput )
{
kdDebug(9006) << "OUTPUT: " << someOutput << endl;
- m_output += someOutput; //append the whole output into one large QStrin
+ m_output += someOutput; //append the whole output into one large TQStrin
}
///////////////////////////////////////////////////////////////////////////////
diff --git a/vcs/cvsservice/editorsdialog.h b/vcs/cvsservice/editorsdialog.h
index 0d0fc287..ffb8b555 100644
--- a/vcs/cvsservice/editorsdialog.h
+++ b/vcs/cvsservice/editorsdialog.h
@@ -22,8 +22,9 @@ class TQStringList;
class EditorsDialog: public EditorsDialogBase, virtual public CVSServiceDCOPIface
{
Q_OBJECT
+ TQ_OBJECT
public:
- EditorsDialog(CvsService_stub *cvsService, TQWidget *parent = 0, const char *name = 0);
+ EditorsDialog(CvsService_stub *cvsService, TQWidget *tqparent = 0, const char *name = 0);
virtual ~EditorsDialog();
void startjob(TQString strDir);
diff --git a/vcs/cvsservice/editorsdialogbase.ui b/vcs/cvsservice/editorsdialogbase.ui
index b0cb925a..546224f8 100644
--- a/vcs/cvsservice/editorsdialogbase.ui
+++ b/vcs/cvsservice/editorsdialogbase.ui
@@ -1,6 +1,6 @@
<!DOCTYPE UI><UI version="3.3" stdsetdef="1">
<class>EditorsDialogBase</class>
-<widget class="QDialog">
+<widget class="TQDialog">
<property name="name">
<cstring>EditorsDialogBase</cstring>
</property>
@@ -22,7 +22,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLayoutWidget" row="1" column="0">
+ <widget class="TQLayoutWidget" row="1" column="0">
<property name="name">
<cstring>Layout1</cstring>
</property>
@@ -46,14 +46,14 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>20</height>
</size>
</property>
</spacer>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>buttonCancel</cstring>
</property>
@@ -69,7 +69,7 @@
</widget>
</hbox>
</widget>
- <widget class="QTextBrowser" row="0" column="0">
+ <widget class="TQTextBrowser" row="0" column="0">
<property name="name">
<cstring>m_textBrowser</cstring>
</property>
@@ -84,5 +84,5 @@
<slot>close()</slot>
</connection>
</connections>
-<layoutdefaults spacing="6" margin="11"/>
+<tqlayoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/vcs/cvsservice/integrator/Makefile.am b/vcs/cvsservice/integrator/Makefile.am
index 7768aad5..fd1d6922 100644
--- a/vcs/cvsservice/integrator/Makefile.am
+++ b/vcs/cvsservice/integrator/Makefile.am
@@ -1,6 +1,6 @@
INCLUDES = -I$(top_srcdir)/lib/interfaces \
-I$(top_srcdir)/lib/interfaces/extensions -I$(top_srcdir)/lib/interfaces/extras -I$(top_srcdir)/lib/util \
- $(all_includes)
+ $(all_includes) -I$(kde_includes)/kde
METASOURCES = AUTO
kde_module_LTLIBRARIES = libcvsserviceintegrator.la
libcvsserviceintegrator_la_LDFLAGS = -avoid-version -no-undefined $(all_libraries)
diff --git a/vcs/cvsservice/integrator/cvsserviceintegrator.cpp b/vcs/cvsservice/integrator/cvsserviceintegrator.cpp
index 1bbc3b11..13cc370e 100644
--- a/vcs/cvsservice/integrator/cvsserviceintegrator.cpp
+++ b/vcs/cvsservice/integrator/cvsserviceintegrator.cpp
@@ -28,9 +28,9 @@ static const KDevPluginInfo data("kdevcvsserviceintegrator");
typedef KDevGenericFactory<CVSServiceIntegrator> CVSIntegratorFactory;
K_EXPORT_COMPONENT_FACTORY( libcvsserviceintegrator, CVSIntegratorFactory(data) )
-CVSServiceIntegrator::CVSServiceIntegrator(TQObject* parent, const char* name,
+CVSServiceIntegrator::CVSServiceIntegrator(TQObject* tqparent, const char* name,
const TQStringList args)
- :KDevVCSIntegrator(parent, name)
+ :KDevVCSIntegrator(tqparent, name)
{
}
@@ -38,14 +38,14 @@ CVSServiceIntegrator::~CVSServiceIntegrator( )
{
}
-VCSDialog* CVSServiceIntegrator::fetcher(TQWidget* parent)
+VCSDialog* CVSServiceIntegrator::fetcher(TQWidget* tqparent)
{
return 0;
}
-VCSDialog* CVSServiceIntegrator::integrator(TQWidget* parent)
+VCSDialog* CVSServiceIntegrator::integrator(TQWidget* tqparent)
{
- IntegratorDlg *dlg = new IntegratorDlg(this, parent);
+ IntegratorDlg *dlg = new IntegratorDlg(this, tqparent);
return dlg;
}
diff --git a/vcs/cvsservice/integrator/cvsserviceintegrator.h b/vcs/cvsservice/integrator/cvsserviceintegrator.h
index c02547a4..02c94430 100644
--- a/vcs/cvsservice/integrator/cvsserviceintegrator.h
+++ b/vcs/cvsservice/integrator/cvsserviceintegrator.h
@@ -26,12 +26,13 @@
class CVSServiceIntegrator: public KDevVCSIntegrator {
Q_OBJECT
+ TQ_OBJECT
public:
- CVSServiceIntegrator(TQObject* parent, const char* name, const TQStringList args = TQStringList());
+ CVSServiceIntegrator(TQObject* tqparent, const char* name, const TQStringList args = TQStringList());
virtual ~CVSServiceIntegrator();
- virtual VCSDialog* fetcher(TQWidget* parent);
- virtual VCSDialog* integrator(TQWidget* parent);
+ virtual VCSDialog* fetcher(TQWidget* tqparent);
+ virtual VCSDialog* integrator(TQWidget* tqparent);
};
diff --git a/vcs/cvsservice/integrator/fetcherdlgbase.ui b/vcs/cvsservice/integrator/fetcherdlgbase.ui
index be0556c2..caf30c0d 100644
--- a/vcs/cvsservice/integrator/fetcherdlgbase.ui
+++ b/vcs/cvsservice/integrator/fetcherdlgbase.ui
@@ -1,6 +1,6 @@
<!DOCTYPE UI><UI version="3.2" stdsetdef="1">
<class>FetcherDlgBase</class>
-<widget class="QDialog">
+<widget class="TQDialog">
<property name="name">
<cstring>FetcherDlgBase</cstring>
</property>
@@ -19,7 +19,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QComboBox" row="1" column="1">
+ <widget class="TQComboBox" row="1" column="1">
<property name="name">
<cstring>module</cstring>
</property>
@@ -35,7 +35,7 @@
<bool>true</bool>
</property>
</widget>
- <widget class="QLabel" row="2" column="0">
+ <widget class="TQLabel" row="2" column="0">
<property name="name">
<cstring>textLabel1_2_2</cstring>
</property>
@@ -54,7 +54,7 @@
<cstring>comboBox5</cstring>
</property>
</widget>
- <widget class="QLabel" row="0" column="0">
+ <widget class="TQLabel" row="0" column="0">
<property name="name">
<cstring>textLabel1</cstring>
</property>
@@ -73,7 +73,7 @@
<cstring>repository</cstring>
</property>
</widget>
- <widget class="QComboBox" row="0" column="1" rowspan="1" colspan="2">
+ <widget class="TQComboBox" row="0" column="1" rowspan="1" colspan="2">
<property name="name">
<cstring>repository</cstring>
</property>
@@ -81,7 +81,7 @@
<bool>true</bool>
</property>
</widget>
- <widget class="QPushButton" row="1" column="2">
+ <widget class="TQPushButton" row="1" column="2">
<property name="name">
<cstring>pushButton2</cstring>
</property>
@@ -97,7 +97,7 @@
<string>Fetch &amp;List</string>
</property>
</widget>
- <widget class="QLabel" row="1" column="0">
+ <widget class="TQLabel" row="1" column="0">
<property name="name">
<cstring>textLabel1_2</cstring>
</property>
@@ -116,7 +116,7 @@
<cstring>module</cstring>
</property>
</widget>
- <widget class="QComboBox" row="2" column="1" rowspan="1" colspan="2">
+ <widget class="TQComboBox" row="2" column="1" rowspan="1" colspan="2">
<property name="name">
<cstring>comboBox5</cstring>
</property>
@@ -134,7 +134,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -149,5 +149,5 @@
<tabstop>pushButton2</tabstop>
<tabstop>comboBox5</tabstop>
</tabstops>
-<layoutdefaults spacing="6" margin="11"/>
+<tqlayoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/vcs/cvsservice/integrator/initdlg.ui b/vcs/cvsservice/integrator/initdlg.ui
index 1b36ecfb..c4d0cc4a 100644
--- a/vcs/cvsservice/integrator/initdlg.ui
+++ b/vcs/cvsservice/integrator/initdlg.ui
@@ -1,6 +1,6 @@
<!DOCTYPE UI><UI version="3.2" stdsetdef="1">
<class>InitDlg</class>
-<widget class="QWidget">
+<widget class="TQWidget">
<property name="name">
<cstring>InitDlg</cstring>
</property>
@@ -19,7 +19,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel" row="0" column="0">
+ <widget class="TQLabel" row="0" column="0">
<property name="name">
<cstring>textLabel1_2_2_2</cstring>
</property>
@@ -53,7 +53,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -62,7 +62,7 @@
</spacer>
</grid>
</widget>
-<layoutdefaults spacing="6" margin="11"/>
+<tqlayoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kurlrequester.h</includehint>
<includehint>klineedit.h</includehint>
diff --git a/vcs/cvsservice/integrator/integratordlg.cpp b/vcs/cvsservice/integrator/integratordlg.cpp
index 32184c45..3561f7ad 100644
--- a/vcs/cvsservice/integrator/integratordlg.cpp
+++ b/vcs/cvsservice/integrator/integratordlg.cpp
@@ -40,8 +40,8 @@
#include "initdlg.h"
-IntegratorDlg::IntegratorDlg(CVSServiceIntegrator *integrator, TQWidget *parent, const char *name)
- :IntegratorDlgBase(parent, name), m_integrator(integrator)
+IntegratorDlg::IntegratorDlg(CVSServiceIntegrator *integrator, TQWidget *tqparent, const char *name)
+ :IntegratorDlgBase(tqparent, name), m_integrator(integrator)
{
TQFile cvspass(TQDir::homeDirPath() + "/.cvspass");
if (cvspass.open(IO_ReadOnly))
@@ -81,11 +81,11 @@ void IntegratorDlg::init_clicked()
if (!proc->normalExit())
KMessageBox::error(this, i18n("cvs init did not exit normally. Please check if cvs is installed and works correctly."), i18n("Init CVS Repository"));
else if (proc->exitStatus() != 0)
- KMessageBox::error(this, i18n("cvs init exited with status %1. Please check if the cvs location is correct.").arg(proc->exitStatus()), i18n("Init CVS Repository"));
+ KMessageBox::error(this, i18n("cvs init exited with status %1. Please check if the cvs location is correct.").tqarg(proc->exitStatus()), i18n("Init CVS Repository"));
else
{
- repository->insertItem(TQString(":local:%1").arg(url));
- repository->setCurrentText(TQString(":local:%1").arg(url));
+ repository->insertItem(TQString(":local:%1").tqarg(url));
+ repository->setCurrentText(TQString(":local:%1").tqarg(url));
}
}
}
@@ -122,13 +122,13 @@ void IntegratorDlg::accept()
proc->setWorkingDirectory(m_projectLocation);
*proc << "cvs";
*proc << "-d" << repository->currentText() << "import"
- << "-m" << TQString("\"%1\"").arg(comment->text()) << module->text()
+ << "-m" << TQString("\"%1\"").tqarg(comment->text()) << module->text()
<< vendorTag->text() << releaseTag->text();
proc->start(KProcess::Block);
if (!proc->normalExit())
KMessageBox::error(this, i18n("cvs import did not exit normally. Please check if cvs is installed and works correctly."), i18n("Init CVS Repository"));
else if (proc->exitStatus() != 0)
- KMessageBox::error(this, i18n("cvs import exited with status %1. Please check if the cvs location is correct.").arg(proc->exitStatus()), i18n("Init CVS Repository"));
+ KMessageBox::error(this, i18n("cvs import exited with status %1. Please check if the cvs location is correct.").tqarg(proc->exitStatus()), i18n("Init CVS Repository"));
else
{
kdDebug() << "Project is in: " << m_projectLocation << endl;
diff --git a/vcs/cvsservice/integrator/integratordlg.h b/vcs/cvsservice/integrator/integratordlg.h
index 5a9ab3a8..72ae30fd 100644
--- a/vcs/cvsservice/integrator/integratordlg.h
+++ b/vcs/cvsservice/integrator/integratordlg.h
@@ -27,8 +27,9 @@ class TQDomDocument;
class IntegratorDlg: public IntegratorDlgBase, public VCSDialog {
Q_OBJECT
+ TQ_OBJECT
public:
- IntegratorDlg(CVSServiceIntegrator *integrator, TQWidget *parent = 0, const char *name = 0);
+ IntegratorDlg(CVSServiceIntegrator *integrator, TQWidget *tqparent = 0, const char *name = 0);
virtual TQWidget *self();
virtual void init(const TQString &projectName, const TQString &projectLocation);
diff --git a/vcs/cvsservice/integrator/integratordlgbase.ui b/vcs/cvsservice/integrator/integratordlgbase.ui
index e17f44e1..a20b7a75 100644
--- a/vcs/cvsservice/integrator/integratordlgbase.ui
+++ b/vcs/cvsservice/integrator/integratordlgbase.ui
@@ -1,6 +1,6 @@
<!DOCTYPE UI><UI version="3.2" stdsetdef="1">
<class>IntegratorDlgBase</class>
-<widget class="QWidget">
+<widget class="TQWidget">
<property name="name">
<cstring>IntegratorDlgBase</cstring>
</property>
@@ -19,7 +19,7 @@
<property name="margin">
<number>0</number>
</property>
- <widget class="QCheckBox" row="0" column="0" rowspan="1" colspan="2">
+ <widget class="TQCheckBox" row="0" column="0" rowspan="1" colspan="2">
<property name="name">
<cstring>createModule</cstring>
</property>
@@ -27,9 +27,9 @@
<string>Create module in the repository</string>
</property>
</widget>
- <widget class="QLayoutWidget" row="1" column="1">
+ <widget class="TQLayoutWidget" row="1" column="1">
<property name="name">
- <cstring>layout1</cstring>
+ <cstring>tqlayout1</cstring>
</property>
<grid>
<property name="name">
@@ -46,7 +46,7 @@
<string>vendor</string>
</property>
</widget>
- <widget class="QPushButton" row="1" column="4">
+ <widget class="TQPushButton" row="1" column="4">
<property name="name">
<cstring>init</cstring>
</property>
@@ -60,7 +60,7 @@
<bool>false</bool>
</property>
</widget>
- <widget class="QComboBox" row="0" column="1" rowspan="1" colspan="4">
+ <widget class="TQComboBox" row="0" column="1" rowspan="1" colspan="4">
<property name="name">
<cstring>repository</cstring>
</property>
@@ -79,7 +79,7 @@
<bool>true</bool>
</property>
</widget>
- <widget class="QPushButton" row="1" column="3">
+ <widget class="TQPushButton" row="1" column="3">
<property name="name">
<cstring>login</cstring>
</property>
@@ -103,7 +103,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>40</width>
<height>20</height>
@@ -120,7 +120,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -135,7 +135,7 @@
<bool>false</bool>
</property>
</widget>
- <widget class="QLabel" row="2" column="0">
+ <widget class="TQLabel" row="2" column="0">
<property name="name">
<cstring>moduleLabel</cstring>
</property>
@@ -157,7 +157,7 @@
<cstring>module</cstring>
</property>
</widget>
- <widget class="QLabel" row="3" column="0">
+ <widget class="TQLabel" row="3" column="0">
<property name="name">
<cstring>vendorLabel</cstring>
</property>
@@ -179,7 +179,7 @@
<cstring>vendorTag</cstring>
</property>
</widget>
- <widget class="QLabel" row="4" column="0">
+ <widget class="TQLabel" row="4" column="0">
<property name="name">
<cstring>releaseLabel</cstring>
</property>
@@ -201,7 +201,7 @@
<cstring>releaseTag</cstring>
</property>
</widget>
- <widget class="QLabel" row="5" column="0">
+ <widget class="TQLabel" row="5" column="0">
<property name="name">
<cstring>commentLabel</cstring>
</property>
@@ -223,7 +223,7 @@
<cstring>comment</cstring>
</property>
</widget>
- <widget class="QLabel" row="0" column="0">
+ <widget class="TQLabel" row="0" column="0">
<property name="name">
<cstring>repositoryLabel</cstring>
</property>
@@ -279,7 +279,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -389,10 +389,10 @@
<tabstop>login</tabstop>
<tabstop>init</tabstop>
</tabstops>
-<slots>
+<Q_SLOTS>
<slot>init_clicked()</slot>
<slot>login_clicked()</slot>
<slot>createModule_clicked()</slot>
-</slots>
-<layoutdefaults spacing="6" margin="11"/>
+</Q_SLOTS>
+<tqlayoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/vcs/cvsservice/releaseinputdialog.cpp b/vcs/cvsservice/releaseinputdialog.cpp
index 91685a29..83df254c 100644
--- a/vcs/cvsservice/releaseinputdialog.cpp
+++ b/vcs/cvsservice/releaseinputdialog.cpp
@@ -20,8 +20,8 @@
// class ReleaseInputDialog
///////////////////////////////////////////////////////////////////////////////
-ReleaseInputDialog::ReleaseInputDialog( TQWidget* parent)
- : ReleaseInputDialogBase( parent, "releaseinputdialog", true, 0 )
+ReleaseInputDialog::ReleaseInputDialog( TQWidget* tqparent)
+ : ReleaseInputDialogBase( tqparent, "releaseinputdialog", true, 0 )
{
}
@@ -47,7 +47,7 @@ TQString ReleaseInputDialog::release() const
else if (type() == byDate)
return " -D " + dateEdit->text();
else
- return TQString::null;
+ return TQString();
}
///////////////////////////////////////////////////////////////////////////////
diff --git a/vcs/cvsservice/releaseinputdialog.h b/vcs/cvsservice/releaseinputdialog.h
index e00b0b04..ef8757bb 100644
--- a/vcs/cvsservice/releaseinputdialog.h
+++ b/vcs/cvsservice/releaseinputdialog.h
@@ -21,13 +21,14 @@
class ReleaseInputDialog : public ReleaseInputDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* C-tor
- * @param parent
+ * @param tqparent
*/
- ReleaseInputDialog( TQWidget* parent = 0 );
+ ReleaseInputDialog( TQWidget* tqparent = 0 );
/**
* Destructor
*/
diff --git a/vcs/cvsservice/releaseinputdialogbase.ui b/vcs/cvsservice/releaseinputdialogbase.ui
index be5bf136..b56ab9ad 100644
--- a/vcs/cvsservice/releaseinputdialogbase.ui
+++ b/vcs/cvsservice/releaseinputdialogbase.ui
@@ -1,6 +1,6 @@
<!DOCTYPE UI><UI version="3.1" stdsetdef="1">
<class>ReleaseInputDialogBase</class>
-<widget class="QDialog">
+<widget class="TQDialog">
<property name="name">
<cstring>ReleaseInputDialogBase</cstring>
</property>
@@ -22,7 +22,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QButtonGroup">
+ <widget class="TQButtonGroup">
<property name="name">
<cstring>buttonGroup1</cstring>
</property>
@@ -37,14 +37,14 @@
<property name="title">
<string>Revision</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignVCenter|AlignLeft</set>
</property>
<vbox>
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QRadioButton">
+ <widget class="TQRadioButton">
<property name="name">
<cstring>headRadio</cstring>
</property>
@@ -55,15 +55,15 @@
<bool>true</bool>
</property>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout3</cstring>
+ <cstring>tqlayout3</cstring>
</property>
<hbox>
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QRadioButton">
+ <widget class="TQRadioButton">
<property name="name">
<cstring>revisionRadio</cstring>
</property>
@@ -90,15 +90,15 @@
</widget>
</hbox>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout2</cstring>
+ <cstring>tqlayout2</cstring>
</property>
<hbox>
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QRadioButton">
+ <widget class="TQRadioButton">
<property name="name">
<cstring>dateRadio</cstring>
</property>
@@ -121,7 +121,7 @@
</widget>
</vbox>
</widget>
- <widget class="QGroupBox">
+ <widget class="TQGroupBox">
<property name="name">
<cstring>groupBox1</cstring>
</property>
@@ -132,7 +132,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QCheckBox" row="0" column="0">
+ <widget class="TQCheckBox" row="0" column="0">
<property name="name">
<cstring>revertCheck</cstring>
</property>
@@ -156,9 +156,9 @@
<enum>Horizontal</enum>
</property>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout2</cstring>
+ <cstring>tqlayout2</cstring>
</property>
<hbox>
<property name="name">
@@ -174,14 +174,14 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>140</width>
<height>20</height>
</size>
</property>
</spacer>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>buttonOk</cstring>
</property>
@@ -198,7 +198,7 @@
<bool>true</bool>
</property>
</widget>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>buttonCancel</cstring>
</property>
@@ -242,5 +242,5 @@
<slot>setEnabled(bool)</slot>
</connection>
</connections>
-<layoutdefaults spacing="6" margin="11"/>
+<tqlayoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/vcs/cvsservice/tagdialog.cpp b/vcs/cvsservice/tagdialog.cpp
index 33aca057..b3d3a42e 100644
--- a/vcs/cvsservice/tagdialog.cpp
+++ b/vcs/cvsservice/tagdialog.cpp
@@ -18,8 +18,8 @@
// class TagDialog
///////////////////////////////////////////////////////////////////////////////
-TagDialog::TagDialog( const TQString &caption, TQWidget *parent, const char *name )
- : TagDialogBase( parent, name ? name : "tagdialog", true )
+TagDialog::TagDialog( const TQString &caption, TQWidget *tqparent, const char *name )
+ : TagDialogBase( tqparent, name ? name : "tagdialog", true )
{
if (!caption.isEmpty())
{
diff --git a/vcs/cvsservice/tagdialog.h b/vcs/cvsservice/tagdialog.h
index 6c34cfe9..e58b912d 100644
--- a/vcs/cvsservice/tagdialog.h
+++ b/vcs/cvsservice/tagdialog.h
@@ -23,8 +23,9 @@
class TagDialog : public TagDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- TagDialog( const TQString &caption, TQWidget *parent = 0, const char *name = 0 );
+ TagDialog( const TQString &caption, TQWidget *tqparent = 0, const char *name = 0 );
virtual ~TagDialog();
/**
diff --git a/vcs/cvsservice/tagdialogbase.ui b/vcs/cvsservice/tagdialogbase.ui
index ce816c2d..db85f0cc 100644
--- a/vcs/cvsservice/tagdialogbase.ui
+++ b/vcs/cvsservice/tagdialogbase.ui
@@ -1,6 +1,6 @@
<!DOCTYPE UI><UI version="3.1" stdsetdef="1">
<class>TagDialogBase</class>
-<widget class="QDialog">
+<widget class="TQDialog">
<property name="name">
<cstring>TagDialogBase</cstring>
</property>
@@ -22,15 +22,15 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout3</cstring>
+ <cstring>tqlayout3</cstring>
</property>
<hbox>
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>textLabel1</cstring>
</property>
@@ -48,7 +48,7 @@
</widget>
</hbox>
</widget>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>tagAsBranchCheck</cstring>
</property>
@@ -56,7 +56,7 @@
<string>Tag as &amp;branch</string>
</property>
</widget>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>forceCheck</cstring>
</property>
@@ -81,9 +81,9 @@
<enum>Horizontal</enum>
</property>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout2</cstring>
+ <cstring>tqlayout2</cstring>
</property>
<hbox>
<property name="name">
@@ -99,14 +99,14 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>200</width>
<height>20</height>
</size>
</property>
</spacer>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>buttonOk</cstring>
</property>
@@ -123,7 +123,7 @@
<bool>true</bool>
</property>
</widget>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>buttonCancel</cstring>
</property>
@@ -155,5 +155,5 @@
<slot>reject()</slot>
</connection>
</connections>
-<layoutdefaults spacing="6" margin="11"/>
+<tqlayoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/vcs/cvsservice/cvsfileinfoprovider.cpp b/vcs/cvsservice/cvsfileinfoprovider.cpp
index cbfc726f..9eb57fcf 100644
--- a/vcs/cvsservice/cvsfileinfoprovider.cpp
+++ b/vcs/cvsservice/cvsfileinfoprovider.cpp
@@ -31,8 +31,8 @@
// class CVSFileInfoProvider
///////////////////////////////////////////////////////////////////////////////
-CVSFileInfoProvider::CVSFileInfoProvider( CvsServicePart *parent, CvsService_stub *cvsService )
- : KDevVCSFileInfoProvider( parent, "cvsfileinfoprovider" ),
+CVSFileInfoProvider::CVSFileInfoProvider( CvsServicePart *tqparent, CvsService_stub *cvsService )
+ : KDevVCSFileInfoProvider( tqparent, "cvsfileinfoprovider" ),
m_requestStatusJob( 0 ), m_cvsService( cvsService ), m_cachedDirEntries( 0 )
{
connect( this, TQT_SIGNAL(needStatusUpdate(const CVSDir&)), this, TQT_SLOT(updateStatusFor(const CVSDir&)));
@@ -59,14 +59,14 @@ const VCSFileInfoMap *CVSFileInfoProvider::status( const TQString &dirPath )
delete m_cachedDirEntries;
CVSDir cvsdir( projectDirectory() + TQDir::separator() + dirPath );
m_previousDirPath = dirPath;
- m_cachedDirEntries = cvsdir.cacheableDirStatus();
+ m_cachedDirEntries = cvsdir.cacheableDirtqStatus();
}
return m_cachedDirEntries;
}
///////////////////////////////////////////////////////////////////////////////
-bool CVSFileInfoProvider::requestStatus( const TQString &dirPath, void *callerData, bool recursive, bool checkRepos )
+bool CVSFileInfoProvider::requesttqStatus( const TQString &dirPath, void *callerData, bool recursive, bool checkRepos )
{
m_savedCallerData = callerData;
if (m_requestStatusJob)
@@ -131,13 +131,13 @@ void CVSFileInfoProvider::propagateUpdate()
void CVSFileInfoProvider::updateStatusFor(const CVSDir& dir)
{
- m_cachedDirEntries = dir.cacheableDirStatus();
+ m_cachedDirEntries = dir.cacheableDirtqStatus();
printOutFileInfoMap( *m_cachedDirEntries );
/* FileTree will call requestStatus() everytime the user expands a directory
* Unfortunatly requestStatus() will be called before the
* VCSFileTreeViewItem of the directory will be filled with the files
- * it contains. Meaning, m_savedCallerData contains no childs at that
+ * it tqcontains. Meaning, m_savedCallerData contains no childs at that
* time. When a dcop call is made to run "cvs status" this is no problem.
* The dcop call takes quit long, and so FileTree has enough time the fill
* in the childs before we report the status back.
@@ -196,7 +196,7 @@ VCSFileInfoMap *CVSFileInfoProvider::parse( TQStringList stringStream )
{
TQRegExp rx_recordStart( "^=+$" );
TQRegExp rx_fileName( "^File: (\\.|\\-|\\w)+" );
- TQRegExp rx_fileStatus( "Status: (\\.|-|\\s|\\w)+" );
+ TQRegExp rx_filetqStatus( "tqStatus: (\\.|-|\\s|\\w)+" );
TQRegExp rx_fileWorkRev( "\\bWorking revision:" );
TQRegExp rx_fileRepoRev( "\\bRepository revision:" );
//TQRegExp rx_stickyTag( "\\s+(Sticky Tag:\\W+(w+|\\(none\\)))" );
@@ -204,7 +204,7 @@ VCSFileInfoMap *CVSFileInfoProvider::parse( TQStringList stringStream )
//TQRegExp rx_stickyOptions( "" ); //@todo
TQString fileName,
- fileStatus,
+ filetqStatus,
workingRevision,
repositoryRevision,
stickyTag,
@@ -224,16 +224,16 @@ VCSFileInfoMap *CVSFileInfoProvider::parse( TQStringList stringStream )
if (rx_recordStart.exactMatch( s ))
state = 1;
- else if (state == 1 && rx_fileName.search( s ) >= 0 && rx_fileStatus.search( s ) >= 0) // FileName
+ else if (state == 1 && rx_fileName.search( s ) >= 0 && rx_filetqStatus.search( s ) >= 0) // FileName
{
- fileName = rx_fileName.cap().replace( "File:", "" ).stripWhiteSpace();
- fileStatus = rx_fileStatus.cap().replace( "Status:", "" ).stripWhiteSpace();
+ fileName = rx_fileName.cap().tqreplace( "File:", "" ).stripWhiteSpace();
+ filetqStatus = rx_filetqStatus.cap().tqreplace( "tqStatus:", "" ).stripWhiteSpace();
++state; // Next state
- kdDebug(9006) << ">> " << fileName << ", " << fileStatus << endl;
+ kdDebug(9006) << ">> " << fileName << ", " << filetqStatus << endl;
}
else if (state == 2 && rx_fileWorkRev.search( s ) >= 0)
{
- workingRevision = s.replace( "Working revision:", "" ).stripWhiteSpace();
+ workingRevision = s.tqreplace( "Working revision:", "" ).stripWhiteSpace();
TQRegExp rx_revision( "\\b(((\\d)+\\.?)*|New file!)" );
if (rx_revision.search( workingRevision ) >= 0)
@@ -245,7 +245,7 @@ VCSFileInfoMap *CVSFileInfoProvider::parse( TQStringList stringStream )
}
else if (state == 3 && rx_fileRepoRev.search( s ) >= 0)
{
- repositoryRevision = s.replace( "Repository revision:", "" ).stripWhiteSpace();
+ repositoryRevision = s.tqreplace( "Repository revision:", "" ).stripWhiteSpace();
TQRegExp rx_revision( "\\b(((\\d)+\\.?)*|No revision control file)" );
if (rx_revision.search( s ) >= 0)
@@ -266,7 +266,7 @@ VCSFileInfoMap *CVSFileInfoProvider::parse( TQStringList stringStream )
{
// Package stuff, put into map and get ready for a new record
VCSFileInfo vcsInfo( fileName, workingRevision, repositoryRevision,
- String2EnumState( fileStatus ) );
+ String2EnumState( filetqStatus ) );
kdDebug(9006) << "== Inserting: " << vcsInfo.toString() << endl;
vcsStates->insert( fileName, vcsInfo );
}
@@ -311,4 +311,4 @@ void CVSFileInfoProvider::printOutFileInfoMap( const VCSFileInfoMap &map )
}
#include "cvsfileinfoprovider.moc"
-// kate: space-indent on; indent-width 4; replace-tabs on;
+// kate: space-indent on; indent-width 4; tqreplace-tabs on;
@@ -131,13 +131,13 @@ void CVSFileInfoProvider::propagateUpdate()
printOutFileInfoMap( *m_cachedDirEntries );
- /* FileTree will call requestStatus() everytime the user expands a directory
- * Unfortunatly requestStatus() will be called before the
+ /* FileTree will call requesttqStatus() everytime the user expands a directory
+ * Unfortunatly requesttqStatus() will be called before the
* VCSFileTreeViewItem of the directory will be filled with the files
diff --git a/vcs/cvsservice/cvspart.cpp b/vcs/cvsservice/cvspart.cpp
index 30a8a700..c95d5e2e 100644
--- a/vcs/cvsservice/cvspart.cpp
+++ b/vcs/cvsservice/cvspart.cpp
@@ -80,8 +80,8 @@ K_EXPORT_COMPONENT_FACTORY( libkdevcvsservice, CvsFactory( data ) )
// class CvsServicePart
///////////////////////////////////////////////////////////////////////////////
-CvsServicePart::CvsServicePart( TQObject *parent, const char *name, const TQStringList & )
- : KDevVersionControl( &data, parent,
+CvsServicePart::CvsServicePart( TQObject *tqparent, const char *name, const TQStringList & )
+ : KDevVersionControl( &data, tqparent,
name ? name : "CvsService" ),
actionCommit( 0 ), actionDiff( 0 ), actionLog( 0 ), actionAnnotate(0), actionAdd( 0 ),
actionAddBinary( 0 ), actionRemove( 0 ), actionUpdate( 0 ),
@@ -283,9 +283,9 @@ void CvsServicePart::projectConfigWidget( KDialogBase *dlg )
///////////////////////////////////////////////////////////////////////////////
-TQWidget* CvsServicePart::newProjectWidget( TQWidget *parent )
+TQWidget* CvsServicePart::newProjectWidget( TQWidget *tqparent )
{
- m_cvsConfigurationForm = new CvsForm( parent, "cvsform" );
+ m_cvsConfigurationForm = new CvsForm( tqparent, "cvsform" );
return m_cvsConfigurationForm;
}
@@ -321,47 +321,47 @@ void CvsServicePart::contextMenu( TQPopupMenu *popup, const Context *context )
popup->insertSeparator();
int id = subMenu->insertItem( actionCommit->text(), this, TQT_SLOT(slotCommit()) );
- subMenu->setWhatsThis(id, i18n("<b>Commit file(s)</b><p>Commits file to repository if modified."));
+ subMenu->tqsetWhatsThis(id, i18n("<b>Commit file(s)</b><p>Commits file to repository if modified."));
// CvsService let to do log and diff operations only on one file (or directory) at time
if (m_urls.count() == 1)
{
id = subMenu->insertItem( actionDiff->text(), this, TQT_SLOT(slotDiff()) );
- subMenu->setWhatsThis(id, i18n("<b>Build difference</b><p>Builds difference between releases."));
+ subMenu->tqsetWhatsThis(id, i18n("<b>Build difference</b><p>Builds difference between releases."));
id = subMenu->insertItem( actionLog->text(), this, TQT_SLOT(slotLog()) );
- subMenu->setWhatsThis(id, i18n("<b>Generate log</b><p>Produces log for this file."));
+ subMenu->tqsetWhatsThis(id, i18n("<b>Generate log</b><p>Produces log for this file."));
id = subMenu->insertItem( actionAnnotate->text(), this, TQT_SLOT(slotAnnotate()) );
- subMenu->setWhatsThis(id, i18n("<b>Generate Annotate</b><p>Produces annotation output for this file."));
+ subMenu->tqsetWhatsThis(id, i18n("<b>Generate Annotate</b><p>Produces annotation output for this file."));
}
id = subMenu->insertItem( actionEditors->text(), this, TQT_SLOT(slotEditors()) );
- subMenu->setWhatsThis(id, i18n("<b>Show editors</b><p>Shows the list of users who are editing files."));
+ subMenu->tqsetWhatsThis(id, i18n("<b>Show editors</b><p>Shows the list of users who are editing files."));
id = subMenu->insertItem( actionEdit->text(), this, TQT_SLOT(slotEdit()) );
- subMenu->setWhatsThis(id, i18n("<b>Mark as beeing edited</b><p>Mark the files as beeing edited."));
+ subMenu->tqsetWhatsThis(id, i18n("<b>Mark as beeing edited</b><p>Mark the files as beeing edited."));
id = subMenu->insertItem( actionUnEdit->text(), this, TQT_SLOT(slotUnEdit()) );
- subMenu->setWhatsThis(id, i18n("<b>Remove editing mark</b><p>Remove the editing mark from the files."));
+ subMenu->tqsetWhatsThis(id, i18n("<b>Remove editing mark</b><p>Remove the editing mark from the files."));
id = subMenu->insertItem( actionAdd->text(), this, TQT_SLOT(slotAdd()) );
- subMenu->setWhatsThis(id, i18n("<b>Add to repository</b><p>Adds file to repository."));
+ subMenu->tqsetWhatsThis(id, i18n("<b>Add to repository</b><p>Adds file to repository."));
id = subMenu->insertItem( actionAddBinary->text(), this, TQT_SLOT(slotAddBinary()) );
- subMenu->setWhatsThis(id, i18n("<b>Add to repository as binary</b><p>Adds file to repository as binary (-kb option)."));
+ subMenu->tqsetWhatsThis(id, i18n("<b>Add to repository as binary</b><p>Adds file to repository as binary (-kb option)."));
id = subMenu->insertItem( actionRemove->text(), this, TQT_SLOT(slotRemove()) );
- subMenu->setWhatsThis(id, i18n("<b>Remove from repository</b><p>Removes file(s) from repository."));
+ subMenu->tqsetWhatsThis(id, i18n("<b>Remove from repository</b><p>Removes file(s) from repository."));
subMenu->insertSeparator();
id = subMenu->insertItem( actionTag->text(), this, TQT_SLOT(slotTag()) );
- subMenu->setWhatsThis(id, i18n("<b>Make tag/branch</b><p>Tags/branches selected file(s)."));
+ subMenu->tqsetWhatsThis(id, i18n("<b>Make tag/branch</b><p>Tags/branches selected file(s)."));
id = subMenu->insertItem( actionUnTag->text(), this, TQT_SLOT(slotUnTag()) );
- subMenu->setWhatsThis(id, i18n("<b>Delete tag</b><p>Delete tag from selected file(s)."));
+ subMenu->tqsetWhatsThis(id, i18n("<b>Delete tag</b><p>Delete tag from selected file(s)."));
id = subMenu->insertItem( actionUpdate->text(), this, TQT_SLOT(slotUpdate()) );
- subMenu->setWhatsThis(id, i18n("<b>Update/revert to another release</b><p>Updates/reverts file(s) to another release."));
+ subMenu->tqsetWhatsThis(id, i18n("<b>Update/revert to another release</b><p>Updates/reverts file(s) to another release."));
id = subMenu->insertItem( actionRemoveSticky->text(), this, TQT_SLOT(slotRemoveSticky()) );
- subMenu->setWhatsThis(id, i18n("<b>Remove sticky flag</b><p>Removes sticky flag from file(s)."));
+ subMenu->tqsetWhatsThis(id, i18n("<b>Remove sticky flag</b><p>Removes sticky flag from file(s)."));
subMenu->insertSeparator();
id = subMenu->insertItem( actionAddToIgnoreList->text(), this, TQT_SLOT(slotAddToIgnoreList()) );
- subMenu->setWhatsThis(id, i18n("<b>Ignore in CVS operations</b><p>Ignore file(s) by adding it to .cvsignore file."));
+ subMenu->tqsetWhatsThis(id, i18n("<b>Ignore in CVS operations</b><p>Ignore file(s) by adding it to .cvsignore file."));
id = subMenu->insertItem( actionRemoveFromIgnoreList->text(), this, TQT_SLOT(slotRemoveFromIgnoreList()) );
- subMenu->setWhatsThis(id, i18n("<b>Do not ignore in CVS operations</b><p>Do not ignore file(s) by removing\nit from .cvsignore file."));
+ subMenu->tqsetWhatsThis(id, i18n("<b>Do not ignore in CVS operations</b><p>Do not ignore file(s) by removing\nit from .cvsignore file."));
- // Now insert in parent menu
+ // Now insert in tqparent menu
popup->insertItem( i18n("CvsService"), subMenu );
// If the current project doesn't support CVS, we don't
diff --git a/vcs/cvsservice/cvspart.h b/vcs/cvsservice/cvspart.h
index b774d682..886d13b2 100644
--- a/vcs/cvsservice/cvspart.h
+++ b/vcs/cvsservice/cvspart.h
@@ -37,20 +37,21 @@ class CvsServicePartImpl;
class CvsServicePart : public KDevVersionControl
{
Q_OBJECT
+ TQ_OBJECT
friend class CvsServicePartImpl;
public:
//! Standard constructor.
- CvsServicePart( TQObject *parent, const char *name, const TQStringList & );
+ CvsServicePart( TQObject *tqparent, const char *name, const TQStringList & );
//! Destructor.
virtual ~CvsServicePart();
/**
* Returns the configuration widget (for properly configuring the project to
* use CVS), child of @p parent.
*/
- virtual TQWidget *newProjectWidget( TQWidget *parent );
+ virtual TQWidget *newProjectWidget( TQWidget *tqparent );
/**
* Setup a directory tree for use with CVS.
*/
@@ -37,20 +37,21 @@ class CvsServicePartImpl;
/**
* Returns the configuration widget (for properly configuring the project to
- * use CVS), child of @p parent.
+ * use CVS), child of @p tqparent.
*/